;;; math-symbol-lists.el --- Lists of Unicode math symbols and latex commands
;;
;; Copyright (C) 2014 Free Software Foundation, Inc.
;; Author: Vitalie Spinu
;; URL: https://github.com/vspinu/math-symbol-lists
;; Package-Version: 20151215.1043
;; Keywords: Unicode, symbols, mathematics
;; Version: 1.0
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;; This file is part of GNU Emacs.
;;
;; This program is free software; you can redistribute it and/or
;; modify it under the terms of the GNU General Public License as
;; published by the Free Software Foundation; either version 3, or
;; (at your option) any later version.
;;
;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
;; General Public License for more details.
;;
;; You should have received a copy of the GNU General Public License
;; along with this program; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth
;; Floor, Boston, MA 02110-1301, USA.
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;; Commentary:
;;
;; This is a "storage" package used by completion engines such as
;; `company-math.el` and `ac-math.el`.
;;
;; Defined (a)lists are:
;;
;;          symbols-math-basic
;;          symbols-math-extended
;;          symbols-latex-commands
;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;
;;; Code:

(defconst math-symbol-list-basic
  '(("Greek Lowercase"	"\\alpha"	#X3B1)
    ("Greek Lowercase"	"\\beta"	#X3B2)
    ("Greek Lowercase"	"\\gamma"	#X3B3)
    ("Greek Lowercase"	"\\delta"	#X3B4)
    ("Greek Lowercase"	"\\epsilon"	#X3F5)
    ("Greek Lowercase"	"\\zeta"	#X3B6)
    ("Greek Lowercase"	"\\eta"	#X3B7)
    ("Greek Lowercase"	"\\theta"	#X3B8)
    ("Greek Lowercase"	"\\iota"	#X3B9)
    ("Greek Lowercase"	"\\kappa"	#X3BA)
    ("Greek Lowercase"	"\\lambda"	#X3BB)
    ("Greek Lowercase"	"\\mu"	#X3BC)
    ("Greek Lowercase"	"\\nu"	#X3BD)
    ("Greek Lowercase"	"\\xi"	#X3BE)
    ("Greek Lowercase"	"\\pi"	#X3C0)
    ("Greek Lowercase"	"\\rho"	#X3C1)
    ("Greek Lowercase"	"\\sigma"	#X3C3)
    ("Greek Lowercase"	"\\tau"	#X3C4)
    ("Greek Lowercase"	"\\upsilon"	#X3C5)
    ("Greek Lowercase"	"\\phi"	#X3D5)
    ("Greek Lowercase"	"\\chi"	#X3C7)
    ("Greek Lowercase"	"\\psi"	#X3C8)
    ("Greek Lowercase"	"\\omega"	#X3C9)
    ("Greek Lowercase"	"\\varepsilon"	#X3B5)
    ("Greek Lowercase"	"\\vartheta"	#X3D1)
    ("Greek Lowercase"	"\\varpi"	#X3D6)
    ("Greek Lowercase"	"\\varrho"	#X3F1)
    ("Greek Lowercase"	"\\varsigma"	#X3C2)
    ("Greek Lowercase"	"\\varphi"	#X3C6)
    ("Greek Uppercase"	"\\Gamma"	#X393)
    ("Greek Uppercase"	"\\Delta"	#X394)
    ("Greek Uppercase"	"\\Theta"	#X398)
    ("Greek Uppercase"	"\\Lambda"	#X39B)
    ("Greek Uppercase"	"\\Xi"	#X39E)
    ("Greek Uppercase"	"\\Pi"	#X3A0)
    ("Greek Uppercase"	"\\Sigma"	#X3A3)
    ("Greek Uppercase"	"\\Upsilon"	#X3D2)
    ("Greek Uppercase"	"\\Phi"	#X3A6)
    ("Greek Uppercase"	"\\Psi"	#X3A8)
    ("Greek Uppercase"	"\\Omega"	#X3A9)
    ("Binary Op"	"\\pm"	#XB1)
    ("Binary Op"	"\\mp"	#X2213)
    ("Binary Op"	"\\times"	#XD7)
    ("Binary Op"	"\\div"	#XF7)
    ("Binary Op"	"\\ast"	#X2217)
    ("Binary Op"	"\\star"	#X22C6)
    ("Binary Op"	"\\circ"	#X2218)
    ("Binary Op"	"\\bullet"	#X2219)
    ("Binary Op"	"\\cdot"	#X22C5)
    ("Binary Op"	"\\cap"	#X2229)
    ("Binary Op"	"\\cup"	#X222A)
    ("Binary Op"	"\\uplus"	#X228E)
    ("Binary Op"	"\\sqcap"	#X2293)
    ("Binary Op"	"\\vee"	#X2228)
    ("Binary Op"	"\\wedge"	#X2227)
    ("Binary Op"	"\\setminus"	#X2216)
    ("Binary Op"	"\\wr"	#X2240)
    ("Binary Op"	"\\diamond"	#X22C4)
    ("Binary Op"	"\\bigtriangleup"	#X25B3)
    ("Binary Op"	"\\bigtriangledown"	#X25BD)
    ("Binary Op"	"\\triangleleft"	#X25C1)
    ("Binary Op"	"\\triangleright"	#X25B7)
    ("Binary Op"	"\\lhd")
    ("Binary Op"	"\\rhd")
    ("Binary Op"	"\\unlhd")
    ("Binary Op"	"\\unrhd")
    ("Binary Op"	"\\oplus"	#X2295)
    ("Binary Op"	"\\ominus"	#X2296)
    ("Binary Op"	"\\otimes"	#X2297)
    ("Binary Op"	"\\oslash"	#X2205)
    ("Binary Op"	"\\odot"	#X2299)
    ("Binary Op"	"\\bigcirc"	#X25CB)
    ("Binary Op"	"\\dagger"	#X2020)
    ("Binary Op"	"\\ddagger"	#X2021)
    ("Binary Op"	"\\amalg"	#X2A3F)
    ("Relational"	"\\leq"	#X2264)
    ("Relational"	"\\geq"	#X2265)
    ("Relational"	"\\qed"	#X220E)
    ("Relational"	"\\equiv"	#X2261)
    ("Relational"	"\\models"	#X22A7)
    ("Relational"	"\\prec"	#X227A)
    ("Relational"	"\\succ"	#X227B)
    ("Relational"	"\\sim"	#X223C)
    ("Relational"	"\\perp"	#X27C2)
    ("Relational"	"\\preceq"	#X2AAF)
    ("Relational"	"\\succeq"	#X2AB0)
    ("Relational"	"\\simeq"	#X2243)
    ("Relational"	"\\mid"	#X2223)
    ("Relational"	"\\ll"	#X226A)
    ("Relational"	"\\gg"	#X226B)
    ("Relational"	"\\asymp"	#X224D)
    ("Relational"	"\\parallel"	#X2225)
    ("Relational"	"\\subset"	#X2282)
    ("Relational"	"\\supset"	#X2283)
    ("Relational"	"\\approx"	#X2248)
    ("Relational"	"\\bowtie"	#X22C8)
    ("Relational"	"\\subseteq"	#X2286)
    ("Relational"	"\\supseteq"	#X2287)
    ("Relational"	"\\cong"	#X2245)
    ("Relational"	"\\Join"	#X2A1D)
    ("Relational"	"\\sqsubset"	#X228F)
    ("Relational"	"\\sqsupset"	#X2290)
    ("Relational"	"\\neq"	#X2260)
    ("Relational"	"\\smile"	#X2323)
    ("Relational"	"\\sqsubseteq"	#X2291)
    ("Relational"	"\\sqsupseteq"	#X2292)
    ("Relational"	"\\doteq"	#X2250)
    ("Relational"	"\\frown"	#X2322)
    ("Relational"	"\\in"	#X2208)
    ("Relational"	"\\ni"	#X220B)
    ("Relational"	"\\propto"	#X221D)
    ("Relational"	"\\vdash"	#X22A2)
    ("Relational"	"\\dashv"	#X22A3)
    ("Arrows"	"\\leftarrow"	#X2190)
    ("Arrows"	"\\Leftarrow"	#X21D0)
    ("Arrows"	"\\rightarrow"	#X2192)
    ("Arrows"	"\\Rightarrow"	#X21D2)
    ("Arrows"	"\\leftrightarrow"	#X2194)
    ("Arrows"	"\\Leftrightarrow"	#X21D4)
    ("Arrows"	"\\mapsto"	#X21A6)
    ("Arrows"	"\\hookleftarrow"	#X21A9)
    ("Arrows"	"\\leftharpoonup"	#X21BC)
    ("Arrows"	"\\leftharpoondown"	#X21BD)
    ("Arrows"	"\\longleftarrow"	#X27F5)
    ("Arrows"	"\\Longleftarrow"	#X27F8)
    ("Arrows"	"\\longrightarrow"	#X27F6)
    ("Arrows"	"\\Longrightarrow"	#X27F9)
    ("Arrows"	"\\longleftrightarrow"	#X27F7)
    ("Arrows"	"\\Longleftrightarrow"	#X27FA)
    ("Arrows"	"\\longmapsto"	#X27FC)
    ("Arrows"	"\\hookrightarrow"	#X21AA)
    ("Arrows"	"\\rightharpoonup"	#X21C0)
    ("Arrows"	"\\rightharpoondown"	#X21C1)
    ("Arrows"	"\\uparrow"	#X2191)
    ("Arrows"	"\\Uparrow"	#X21D1)
    ("Arrows"	"\\downarrow"	#X2193)
    ("Arrows"	"\\Downarrow"	#X21D3)
    ("Arrows"	"\\updownarrow"	#X2195)
    ("Arrows"	"\\Updownarrow"	#X21D5)
    ("Arrows"	"\\nearrow"	#X2197)
    ("Arrows"	"\\searrow"	#X2198)
    ("Arrows"	"\\swarrow"	#X2199)
    ("Arrows"	"\\nwarrow"	#X2196)
    ("Punctuation"	"\\ldots"	#X2026)
    ("Punctuation"	"\\cdots"	#X22EF)
    ("Punctuation"	"\\vdots"	#X22EE)
    ("Punctuation"	"\\ddots"	#X22F1)
    ("Punctuation"	"\\colon"	#X3A)
    ("Misc Symbol"	"\\nabla"	#X2207)
    ("Misc Symbol"	"\\aleph"	#X2135)
    ("Misc Symbol"	"\\prime"	#X2032)
    ("Misc Symbol"	"\\forall"	#X2200)
    ("Misc Symbol"	"\\infty"	#X221E)
    ("Misc Symbol"	"\\hbar"	#X210F)
    ("Misc Symbol"	"\\emptyset"	#X2205)
    ("Misc Symbol"	"\\exists"	#X2203)
    ("Misc Symbol"	"\\surd"	#X221A)
    ("Misc Symbol"	"\\Box")
    ("Misc Symbol"	"\\triangle"	#X25B3)
    ("Misc Symbol"	"\\Diamond")
    ("Misc Symbol"	"\\imath"	#X131)
    ("Misc Symbol"	"\\jmath"	#X1D6A5)
    ("Misc Symbol"	"\\ell"	#X2113)
    ("Misc Symbol"	"\\neg"	#XAC)
    ("Misc Symbol"	"\\not"	#X338)
    ("Misc Symbol"	"\\top"	#X22A4)
    ("Misc Symbol"	"\\flat"	#X266D)
    ("Misc Symbol"	"\\natural"	#X266E)
    ("Misc Symbol"	"\\sharp"	#X266F)
    ("Misc Symbol"	"\\wp"	#X2118)
    ("Misc Symbol"	"\\bot"	#X22A5)
    ("Misc Symbol"	"\\clubsuit"	#X2663)
    ("Misc Symbol"	"\\diamondsuit"	#X2662)
    ("Misc Symbol"	"\\heartsuit"	#X2661)
    ("Misc Symbol"	"\\spadesuit"	#X2660)
    ("Misc Symbol"	"\\mho"	#X2127)
    ("Misc Symbol"	"\\Re"	#X211C)
    ("Misc Symbol"	"\\Im"	#X2111)
    ("Misc Symbol"	"\\angle"	#X2220)
    ("Misc Symbol"	"\\partial"	#X2202)
    ("Var Symbol"	"\\sum"	#X2211)
    ("Var Symbol"	"\\prod"	#X220F)
    ("Var Symbol"	"\\coprod"	#X2210)
    ("Var Symbol"	"\\int"	#X222B)
    ("Var Symbol"	"\\oint"	#X222E)
    ("Var Symbol"	"\\bigcap"	#X22C2)
    ("Var Symbol"	"\\bigcup"	#X22C3)
    ("Var Symbol"	"\\bigsqcup"	#X2A06)
    ("Var Symbol"	"\\bigvee"	#X22C1)
    ("Var Symbol"	"\\bigwedge"	#X22C0)
    ("Var Symbol"	"\\bigodot"	#X2A00)
    ("Var Symbol"	"\\bigotimes"	#X2A02)
    ("Var Symbol"	"\\bigoplus"	#X2A01)
    ("Var Symbol"	"\\biguplus"	#X2A04)
    ("Log-like"	"\\arccos")
    ("Log-like"	"\\arcsin")
    ("Log-like"	"\\arctan")
    ("Log-like"	"\\arg")
    ("Log-like"	"\\cos")
    ("Log-like"	"\\cosh")
    ("Log-like"	"\\cot")
    ("Log-like"	"\\coth")
    ("Log-like"	"\\csc")
    ("Log-like"	"\\deg")
    ("Log-like"	"\\det")
    ("Log-like"	"\\dim")
    ("Log-like"	"\\exp")
    ("Log-like"	"\\gcd")
    ("Log-like"	"\\hom")
    ("Log-like"	"\\inf")
    ("Log-like"	"\\ker")
    ("Log-like"	"\\lg")
    ("Log-like"	"\\lim")
    ("Log-like"	"\\liminf")
    ("Log-like"	"\\limsup")
    ("Log-like"	"\\ln")
    ("Log-like"	"\\log")
    ("Log-like"	"\\max")
    ("Log-like"	"\\min")
    ("Log-like"	"\\Pr")
    ("Log-like"	"\\sec")
    ("Log-like"	"\\sin")
    ("Log-like"	"\\sinh")
    ("Log-like"	"\\sup")
    ("Log-like"	"\\tan")
    ("Log-like"	"\\tanh")
    ("Delimiters"	"\\{")
    ("Delimiters"	"\\}")
    ("Delimiters"	"\\lfloor"	#X230A)
    ("Delimiters"	"\\rfloor"	#X230B)
    ("Delimiters"	"\\lceil"	#X2308)
    ("Delimiters"	"\\rceil"	#X2309)
    ("Delimiters"	"\\langle"	#X27E8)
    ("Delimiters"	"\\rangle"	#X27E9)
    ("Delimiters"	"\\rmoustache"	#X23B1)
    ("Delimiters"	"\\lmoustache"	#X23B0)
    ("Delimiters"	"\\rgroup")
    ("Delimiters"	"\\lgroup")
    ("Delimiters"	"\\backslash"	#X5C)
    ("Delimiters"	"\\|")
    ("Delimiters"	"\\arrowvert")
    ("Delimiters"	"\\Arrowvert")
    ("Delimiters"	"\\bracevert")
    ("Constructs"	"\\widetilde"	#X303)
    ("Constructs"	"\\widehat"	#X302)
    ("Constructs"	"\\overleftarrow"	#X20D6)
    ("Constructs"	"\\overrightarrow")
    ("Constructs"	"\\overline")
    ("Constructs"	"\\underline")
    ("Constructs"	"\\overbrace"	#XFE37)
    ("Constructs"	"\\underbrace"	#XFE38)
    ("Constructs"	"\\sqrt"	#X221A)
    ("Constructs"	"\\frac")
    ("Accents"	"\\hat"	#X302)
    ("Accents"	"\\acute"	#X301)
    ("Accents"	"\\bar"	#X304)
    ("Accents"	"\\dot"	#X307)
    ("Accents"	"\\breve"	#X306)
    ("Accents"	"\\check"	#X30C)
    ("Accents"	"\\grave"	#X300)
    ("Accents"	"\\vec"	#X20D7)
    ("Accents"	"\\ddot"	#X308)
    ("Accents"	"\\tilde"	#X303)
    ("AMS/Hebrew"	"\\digamma"	#X3DD)
    ("AMS/Hebrew"	"\\varkappa"	#X3F0)
    ("AMS/Hebrew"	"\\beth"	#X2136)
    ("AMS/Hebrew"	"\\daleth"	#X2138)
    ("AMS/Hebrew"	"\\gimel"	#X2137)
    ("AMS/Greek Uppercase"	"\\varGamma")
    ("AMS/Greek Uppercase"	"\\varDelta")
    ("AMS/Greek Uppercase"	"\\varTheta")
    ("AMS/Greek Uppercase"	"\\varLambda")
    ("AMS/Greek Uppercase"	"\\varXi")
    ("AMS/Greek Uppercase"	"\\varPi")
    ("AMS/Greek Uppercase"	"\\varSigma")
    ("AMS/Greek Uppercase"	"\\varUpsilon")
    ("AMS/Greek Uppercase"	"\\varPhi")
    ("AMS/Greek Uppercase"	"\\varPsi")
    ("AMS/Greek Uppercase"	"\\varOmega")
    ("AMS/Arrows"	"\\dashrightarrow")
    ("AMS/Arrows"	"\\dashleftarrow")
    ("AMS/Arrows"	"\\leftleftarrows"	#X21C7)
    ("AMS/Arrows"	"\\leftrightarrows"	#X21C6)
    ("AMS/Arrows"	"\\Lleftarrow"	#X21DA)
    ("AMS/Arrows"	"\\twoheadleftarrow"	#X219E)
    ("AMS/Arrows"	"\\leftarrowtail"	#X21A2)
    ("AMS/Arrows"	"\\looparrowleft"	#X21AB)
    ("AMS/Arrows"	"\\leftrightharpoons"	#X21CB)
    ("AMS/Arrows"	"\\curvearrowleft"	#X21B6)
    ("AMS/Arrows"	"\\circlearrowleft")
    ("AMS/Arrows"	"\\Lsh"	#X21B0)
    ("AMS/Arrows"	"\\upuparrows"	#X21C8)
    ("AMS/Arrows"	"\\upharpoonleft"	#X21BF)
    ("AMS/Arrows"	"\\downharpoonleft"	#X21C3)
    ("AMS/Arrows"	"\\multimap"	#X22B8)
    ("AMS/Arrows"	"\\leftrightsquigarrow"	#X21AD)
    ("AMS/Arrows"	"\\looparrowright"	#X21AC)
    ("AMS/Arrows"	"\\rightleftharpoons"	#X21CC)
    ("AMS/Arrows"	"\\curvearrowright"	#X21B7)
    ("AMS/Arrows"	"\\circlearrowright")
    ("AMS/Arrows"	"\\Rsh"	#X21B1)
    ("AMS/Arrows"	"\\downdownarrows"	#X21CA)
    ("AMS/Arrows"	"\\upharpoonright"	#X21BE)
    ("AMS/Arrows"	"\\downharpoonright"	#X21C2)
    ("AMS/Arrows"	"\\rightsquigarrow"	#X219D)
    ("AMS/Neg Arrows"	"\\nleftarrow"	#X219A)
    ("AMS/Neg Arrows"	"\\nrightarrow"	#X219B)
    ("AMS/Neg Arrows"	"\\nLeftarrow"	#X21CD)
    ("AMS/Neg Arrows"	"\\nRightarrow"	#X21CF)
    ("AMS/Neg Arrows"	"\\nleftrightarrow"	#X21AE)
    ("AMS/Neg Arrows"	"\\nLeftrightarrow"	#X21CE)
    ("AMS/Relational I"	"\\leqq"	#X2266)
    ("AMS/Relational I"	"\\leqslant"	#X2A7D)
    ("AMS/Relational I"	"\\eqslantless"	#X2A95)
    ("AMS/Relational I"	"\\lesssim"	#X2272)
    ("AMS/Relational I"	"\\lessapprox"	#X2A85)
    ("AMS/Relational I"	"\\approxeq"	#X224A)
    ("AMS/Relational I"	"\\lessdot"	#X22D6)
    ("AMS/Relational I"	"\\lll"	#X22D8)
    ("AMS/Relational I"	"\\lessgtr"	#X2276)
    ("AMS/Relational I"	"\\lesseqgtr"	#X22DA)
    ("AMS/Relational I"	"\\lesseqqgtr"	#X2A8B)
    ("AMS/Relational I"	"\\doteqdot")
    ("AMS/Relational I"	"\\risingdotseq"	#X2253)
    ("AMS/Relational I"	"\\fallingdotseq"	#X2252)
    ("AMS/Relational I"	"\\backsim"	#X223D)
    ("AMS/Relational I"	"\\backsimeq"	#X22CD)
    ("AMS/Relational I"	"\\subseteqq"	#X2AC5)
    ("AMS/Relational I"	"\\Subset"	#X22D0)
    ("AMS/Relational I"	"\\sqsubset"	#X228F)
    ("AMS/Relational I"	"\\preccurlyeq"	#X227C)
    ("AMS/Relational I"	"\\curlyeqprec"	#X22DE)
    ("AMS/Relational I"	"\\precsim"	#X227E)
    ("AMS/Relational I"	"\\precapprox"	#X2AB7)
    ("AMS/Relational I"	"\\vartriangleleft"	#X22B2)
    ("AMS/Relational I"	"\\trianglelefteq"	#X22B4)
    ("AMS/Relational I"	"\\vDash"	#X22A8)
    ("AMS/Relational I"	"\\Vvdash"	#X22AA)
    ("AMS/Relational I"	"\\smallsmile"	#X2323)
    ("AMS/Relational I"	"\\smallfrown"	#X2322)
    ("AMS/Relational I"	"\\bumpeq"	#X224F)
    ("AMS/Relational I"	"\\Bumpeq"	#X224E)
    ("AMS/Relational II"	"\\geqq"	#X2267)
    ("AMS/Relational II"	"\\geqslant"	#X2A7E)
    ("AMS/Relational II"	"\\eqslantgtr"	#X2A96)
    ("AMS/Relational II"	"\\gtrsim"	#X2273)
    ("AMS/Relational II"	"\\gtrapprox"	#X2A86)
    ("AMS/Relational II"	"\\gtrdot"	#X22D7)
    ("AMS/Relational II"	"\\ggg"	#X22D9)
    ("AMS/Relational II"	"\\gtrless"	#X2277)
    ("AMS/Relational II"	"\\gtreqless"	#X22DB)
    ("AMS/Relational II"	"\\gtreqqless"	#X2A8C)
    ("AMS/Relational II"	"\\eqcirc"	#X2256)
    ("AMS/Relational II"	"\\circeq"	#X2257)
    ("AMS/Relational II"	"\\triangleq"	#X225C)
    ("AMS/Relational II"	"\\thicksim"	#X223C)
    ("AMS/Relational II"	"\\thickapprox"	#X2248)
    ("AMS/Relational II"	"\\supseteqq"	#X2AC6)
    ("AMS/Relational II"	"\\Supset"	#X22D1)
    ("AMS/Relational II"	"\\sqsupset"	#X2290)
    ("AMS/Relational II"	"\\succcurlyeq"	#X227D)
    ("AMS/Relational II"	"\\curlyeqsucc"	#X22DF)
    ("AMS/Relational II"	"\\succsim"	#X227F)
    ("AMS/Relational II"	"\\succapprox"	#X2AB8)
    ("AMS/Relational II"	"\\vartriangleright"	#X22B3)
    ("AMS/Relational II"	"\\trianglerighteq"	#X22B5)
    ("AMS/Relational II"	"\\Vdash"	#X22A9)
    ("AMS/Relational II"	"\\shortmid"	#X2223)
    ("AMS/Relational II"	"\\shortparallel"	#X2225)
    ("AMS/Relational II"	"\\between"	#X226C)
    ("AMS/Relational II"	"\\pitchfork"	#X22D4)
    ("AMS/Relational II"	"\\varpropto"	#X221D)
    ("AMS/Relational II"	"\\blacktriangleleft"	#X25C0)
    ("AMS/Relational II"	"\\therefore"	#X2234)
    ("AMS/Relational II"	"\\backepsilon"	#X3F6)
    ("AMS/Relational II"	"\\blacktriangleright"	#X25B6)
    ("AMS/Relational II"	"\\because"	#X2235)
    ("AMS/Neg Rel I"	"\\nless"	#X226E)
    ("AMS/Neg Rel I"	"\\nleq"	#X2270)
    ("AMS/Neg Rel I"	"\\nleqslant")
    ("AMS/Neg Rel I"	"\\nleqq")
    ("AMS/Neg Rel I"	"\\lneq"	#X2A87)
    ("AMS/Neg Rel I"	"\\lneqq"	#X2268)
    ("AMS/Neg Rel I"	"\\lvertneqq")
    ("AMS/Neg Rel I"	"\\lnsim"	#X22E6)
    ("AMS/Neg Rel I"	"\\lnapprox"	#X2A89)
    ("AMS/Neg Rel I"	"\\nprec"	#X2280)
    ("AMS/Neg Rel I"	"\\npreceq")
    ("AMS/Neg Rel I"	"\\precnsim"	#X22E8)
    ("AMS/Neg Rel I"	"\\precnapprox"	#X2AB9)
    ("AMS/Neg Rel I"	"\\nsim"	#X2241)
    ("AMS/Neg Rel I"	"\\nshortmid"	#X2224)
    ("AMS/Neg Rel I"	"\\nmid"	#X2224)
    ("AMS/Neg Rel I"	"\\nvdash"	#X22AC)
    ("AMS/Neg Rel I"	"\\nvDash"	#X22AD)
    ("AMS/Neg Rel I"	"\\ntriangleleft"	#X22EA)
    ("AMS/Neg Rel I"	"\\ntrianglelefteq"	#X22EC)
    ("AMS/Neg Rel I"	"\\nsubseteq"	#X2288)
    ("AMS/Neg Rel I"	"\\subsetneq"	#X228A)
    ("AMS/Neg Rel I"	"\\varsubsetneq")
    ("AMS/Neg Rel I"	"\\subsetneqq"	#X2ACB)
    ("AMS/Neg Rel I"	"\\varsubsetneqq")
    ("AMS/Neg Rel II"	"\\ngtr"	#X226F)
    ("AMS/Neg Rel II"	"\\ngeq"	#X2271)
    ("AMS/Neg Rel II"	"\\ngeqslant")
    ("AMS/Neg Rel II"	"\\ngeqq")
    ("AMS/Neg Rel II"	"\\gneq"	#X2A88)
    ("AMS/Neg Rel II"	"\\gneqq"	#X2269)
    ("AMS/Neg Rel II"	"\\gvertneqq")
    ("AMS/Neg Rel II"	"\\gnsim"	#X22E7)
    ("AMS/Neg Rel II"	"\\gnapprox"	#X2A8A)
    ("AMS/Neg Rel II"	"\\nsucc"	#X2281)
    ("AMS/Neg Rel II"	"\\nsucceq")
    ("AMS/Neg Rel II"	"\\succnsim"	#X22E9)
    ("AMS/Neg Rel II"	"\\succnapprox"	#X2ABA)
    ("AMS/Neg Rel II"	"\\ncong"	#X2247)
    ("AMS/Neg Rel II"	"\\nshortparallel"	#X2226)
    ("AMS/Neg Rel II"	"\\nparallel"	#X2226)
    ("AMS/Neg Rel II"	"\\nvDash"	#X22AD)
    ("AMS/Neg Rel II"	"\\nVDash"	#X22AF)
    ("AMS/Neg Rel II"	"\\ntriangleright"	#X22EB)
    ("AMS/Neg Rel II"	"\\ntrianglerighteq"	#X22ED)
    ("AMS/Neg Rel II"	"\\nsupseteq"	#X2289)
    ("AMS/Neg Rel II"	"\\nsupseteqq")
    ("AMS/Neg Rel II"	"\\supsetneq"	#X228B)
    ("AMS/Neg Rel II"	"\\varsupsetneq")
    ("AMS/Neg Rel II"	"\\supsetneqq"	#X2ACC)
    ("AMS/Neg Rel II"	"\\varsupsetneqq")
    ("AMS/Binary Op"	"\\dotplus"	#X2214)
    ("AMS/Binary Op"	"\\smallsetminus"	#X2216)
    ("AMS/Binary Op"	"\\Cap"	#X22D2)
    ("AMS/Binary Op"	"\\Cup"	#X22D3)
    ("AMS/Binary Op"	"\\barwedge"	#X22BC)
    ("AMS/Binary Op"	"\\veebar"	#X22BB)
    ("AMS/Binary Op"	"\\doublebarwedge"	#X2306)
    ("AMS/Binary Op"	"\\boxminus"	#X229F)
    ("AMS/Binary Op"	"\\boxtimes"	#X22A0)
    ("AMS/Binary Op"	"\\boxdot"	#X22A1)
    ("AMS/Binary Op"	"\\boxplus"	#X229E)
    ("AMS/Binary Op"	"\\divideontimes"	#X22C7)
    ("AMS/Binary Op"	"\\ltimes"	#X22C9)
    ("AMS/Binary Op"	"\\rtimes"	#X22CA)
    ("AMS/Binary Op"	"\\leftthreetimes"	#X22CB)
    ("AMS/Binary Op"	"\\rightthreetimes"	#X22CC)
    ("AMS/Binary Op"	"\\curlywedge"	#X22CF)
    ("AMS/Binary Op"	"\\curlyvee"	#X22CE)
    ("AMS/Binary Op"	"\\circleddash"	#X229D)
    ("AMS/Binary Op"	"\\circledast"	#X229B)
    ("AMS/Binary Op"	"\\circledcirc"	#X229A)
    ("AMS/Binary Op"	"\\centerdot")
    ("AMS/Binary Op"	"\\intercal"	#X22BA)
    ("AMS/Misc"	"\\hbar"	#X210F)
    ("AMS/Misc"	"\\hslash"	#X210F)
    ("AMS/Misc"	"\\vartriangle"	#X25B5)
    ("AMS/Misc"	"\\triangledown"	#X25BF)
    ("AMS/Misc"	"\\square"	#X25A1)
    ("AMS/Misc"	"\\lozenge"	#X25CA)
    ("AMS/Misc"	"\\circledS"	#X24C8)
    ("AMS/Misc"	"\\angle"	#X2220)
    ("AMS/Misc"	"\\measuredangle"	#X2221)
    ("AMS/Misc"	"\\nexists"	#X2204)
    ("AMS/Misc"	"\\mho"	#X2127)
    ("AMS/Misc"	"\\Finv"	#X2132)
    ("AMS/Misc"	"\\Game"	#X2141)
    ("AMS/Misc"	"\\Bbbk"	#X1D55C)
    ("AMS/Misc"	"\\backprime"	#X2035)
    ("AMS/Misc"	"\\varnothing"	#X2205)
    ("AMS/Misc"	"\\blacktriangle"	#X25B4)
    ("AMS/Misc"	"\\blacktriangledown"	#X25BE)
    ("AMS/Misc"	"\\blacksquare"	#X25A0)
    ("AMS/Misc"	"\\blacklozenge"	#X29EB)
    ("AMS/Misc"	"\\bigstar"	#X2605)
    ("AMS/Misc"	"\\sphericalangle"	#X2222)
    ("AMS/Misc"	"\\complement"	#X2201)
    ("AMS/Misc"	"\\eth"	#XF0)
    ("AMS/Misc"	"\\diagup"	#X2571)
    ("AMS/Misc"	"\\diagdown"	#X2572)
    ("AMS/Accents"	"\\dddot"	#X20DB)
    ("AMS/Accents"	"\\ddddot"	#X20DC)
    ("AMS/Delimiters"	"\\bigl")
    ("AMS/Delimiters"	"\\bigr")
    ("AMS/Delimiters"	"\\Bigl")
    ("AMS/Delimiters"	"\\Bigr")
    ("AMS/Delimiters"	"\\biggl")
    ("AMS/Delimiters"	"\\biggr")
    ("AMS/Delimiters"	"\\Biggl")
    ("AMS/Delimiters"	"\\Biggr")
    ("AMS/Delimiters"	"\\lvert")
    ("AMS/Delimiters"	"\\rvert")
    ("AMS/Delimiters"	"\\lVert")
    ("AMS/Delimiters"	"\\rVert")
    ("AMS/Delimiters"	"\\ulcorner"	#X231C)
    ("AMS/Delimiters"	"\\urcorner"	#X231D)
    ("AMS/Delimiters"	"\\llcorner"	#X231E)
    ("AMS/Delimiters"	"\\lrcorner"	#X231F)
    ("AMS/Special"	"\\nobreakdash")
    ("AMS/Special"	"\\leftroot")
    ("AMS/Special"	"\\uproot")
    ("AMS/Special"	"\\accentedsymbol")
    ("AMS/Special"	"\\xleftarrow")
    ("AMS/Special"	"\\xrightarrow")
    ("AMS/Special"	"\\overset")
    ("AMS/Special"	"\\underset")
    ("AMS/Special"	"\\dfrac")
    ("AMS/Special"	"\\genfrac")
    ("AMS/Special"	"\\tfrac")
    ("AMS/Special"	"\\binom")
    ("AMS/Special"	"\\dbinom")
    ("AMS/Special"	"\\tbinom")
    ("AMS/Special"	"\\smash")
    ("AMS/Special"	"\\eucal")
    ("AMS/Special"	"\\boldsymbol")
    ("AMS/Special"	"\\text")
    ("AMS/Special"	"\\intertext")
    ("AMS/Special"	"\\substack")
    ("AMS/Special"	"\\subarray")
    ("AMS/Special"	"\\sideset"))
  "List of basic mathematical symbols.")

(defconst math-symbol-list-extended
  '(("punct"	"\\exclam"	#X21)
    ("ord"	"\\octothorpe"	#X23)
    ("ord"	"\\mathdollar"	#X24)
    ("ord"	"\\percent"	#X25)
    ("ord"	"\\ampersand"	#X26)
    ("open"	"\\lparen"	#X28)
    ("close"	"\\rparen"	#X29)
    ("bin"	"\\plus"	#X2B)
    ("punct"	"\\comma"	#X2C)
    ("alpha"	"\\period"	#X2E)
    ("ord"	"\\mathslash"	#X2F)
    ("punct"	"\\mathcolon"	#X3A)
    ("punct"	"\\semicolon"	#X3B)
    ("rel"	"\\less"	#X3C)
    ("rel"	"\\equal"	#X3D)
    ("rel"	"\\greater"	#X3E)
    ("ord"	"\\question"	#X3F)
    ("ord"	"\\atsign"	#X40)
    ("open"	"\\lbrack"	#X5B)
    ("ord"	"\\backslash"	#X5C)
    ("close"	"\\rbrack"	#X5D)
    ("open"	"\\lbrace"	#X7B)
    ("close"	"\\rbrace"	#X7D)
    ("ord"	"\\sterling"	#XA3)
    ("ord"	"\\yen"	#XA5)
    ("ord"	"\\neg"	#XAC)
    ("bin"	"\\pm"	#XB1)
    ("bin"	"\\cdotp"	#XB7)
    ("bin"	"\\times"	#XD7)
    ("alpha"	"\\matheth"	#XF0)
    ("bin"	"\\div"	#XF7)
    ("ord"	"\\Zbar"	#X1B5)
    ("accent"	"\\grave"	#X300)
    ("accent"	"\\acute"	#X301)
    ("accent"	"\\hat"	#X302)
    ("accent"	"\\tilde"	#X303)
    ("accent"	"\\bar"	#X304)
    ("accent"	"\\overbar"	#X305)
    ("accent"	"\\breve"	#X306)
    ("accent"	"\\dot"	#X307)
    ("accent"	"\\ddot"	#X308)
    ("accent"	"\\ovhook"	#X309)
    ("accent"	"\\ocirc"	#X30A)
    ("accent"	"\\check"	#X30C)
    ("accent"	"\\candra"	#X310)
    ("accent"	"\\oturnedcomma"	#X312)
    ("accent"	"\\ocommatopright"	#X315)
    ("accent"	"\\droang"	#X31A)
    ("accent"	"\\wideutilde"	#X330)
    ("accent"	"\\underbar"	#X331)
    ("accent"	"\\not"	#X338)
    ("alpha"	"\\upAlpha"	#X391)
    ("alpha"	"\\upBeta"	#X392)
    ("alpha"	"\\upGamma"	#X393)
    ("alpha"	"\\upDelta"	#X394)
    ("alpha"	"\\upEpsilon"	#X395)
    ("alpha"	"\\upZeta"	#X396)
    ("alpha"	"\\upEta"	#X397)
    ("alpha"	"\\upTheta"	#X398)
    ("alpha"	"\\upIota"	#X399)
    ("alpha"	"\\upKappa"	#X39A)
    ("alpha"	"\\upLambda"	#X39B)
    ("alpha"	"\\upMu"	#X39C)
    ("alpha"	"\\upNu"	#X39D)
    ("alpha"	"\\upXi"	#X39E)
    ("alpha"	"\\upOmicron"	#X39F)
    ("alpha"	"\\upPi"	#X3A0)
    ("alpha"	"\\upRho"	#X3A1)
    ("alpha"	"\\upSigma"	#X3A3)
    ("alpha"	"\\upTau"	#X3A4)
    ("alpha"	"\\upUpsilon"	#X3A5)
    ("alpha"	"\\upPhi"	#X3A6)
    ("alpha"	"\\upChi"	#X3A7)
    ("alpha"	"\\upPsi"	#X3A8)
    ("alpha"	"\\upOmega"	#X3A9)
    ("alpha"	"\\upalpha"	#X3B1)
    ("alpha"	"\\upbeta"	#X3B2)
    ("alpha"	"\\upgamma"	#X3B3)
    ("alpha"	"\\updelta"	#X3B4)
    ("alpha"	"\\upepsilon"	#X3B5)
    ("alpha"	"\\upzeta"	#X3B6)
    ("alpha"	"\\upeta"	#X3B7)
    ("alpha"	"\\uptheta"	#X3B8)
    ("alpha"	"\\upiota"	#X3B9)
    ("alpha"	"\\upkappa"	#X3BA)
    ("alpha"	"\\uplambda"	#X3BB)
    ("alpha"	"\\upmu"	#X3BC)
    ("alpha"	"\\upnu"	#X3BD)
    ("alpha"	"\\upxi"	#X3BE)
    ("alpha"	"\\upomicron"	#X3BF)
    ("alpha"	"\\uppi"	#X3C0)
    ("alpha"	"\\uprho"	#X3C1)
    ("alpha"	"\\upvarsigma"	#X3C2)
    ("alpha"	"\\upsigma"	#X3C3)
    ("alpha"	"\\uptau"	#X3C4)
    ("alpha"	"\\upupsilon"	#X3C5)
    ("alpha"	"\\upvarphi"	#X3C6)
    ("alpha"	"\\upchi"	#X3C7)
    ("alpha"	"\\uppsi"	#X3C8)
    ("alpha"	"\\upomega"	#X3C9)
    ("alpha"	"\\upvarbeta"	#X3D0)
    ("alpha"	"\\upvartheta"	#X3D1)
    ("alpha"	"\\upUpsilon"	#X3D2)
    ("alpha"	"\\upphi"	#X3D5)
    ("alpha"	"\\upvarpi"	#X3D6)
    ("ord"	"\\upoldKoppa"	#X3D8)
    ("ord"	"\\upoldkoppa"	#X3D9)
    ("alpha"	"\\upStigma"	#X3DA)
    ("alpha"	"\\upstigma"	#X3DB)
    ("alpha"	"\\upDigamma"	#X3DC)
    ("alpha"	"\\updigamma"	#X3DD)
    ("alpha"	"\\upKoppa"	#X3DE)
    ("alpha"	"\\upkoppa"	#X3DF)
    ("alpha"	"\\upSampi"	#X3E0)
    ("alpha"	"\\upsampi"	#X3E1)
    ("alpha"	"\\upvarkappa"	#X3F0)
    ("alpha"	"\\upvarrho"	#X3F1)
    ("alpha"	"\\upvarTheta"	#X3F4)
    ("alpha"	"\\upvarepsilon"	#X3F5)
    ("ord"	"\\upbackepsilon"	#X3F6)
    ("ord"	"\\horizbar"	#X2015)
    ("fence"	"\\Vert"	#X2016)
    ("ord"	"\\twolowline"	#X2017)
    ("bin"	"\\dagger"	#X2020)
    ("bin"	"\\ddagger"	#X2021)
    ("bin"	"\\smblkcircle"	#X2022)
    ("ord"	"\\enleadertwodots"	#X2025)
    ("ord"	"\\unicodeellipsis"	#X2026)
    ("ord"	"\\prime"	#X2032)
    ("ord"	"\\dprime"	#X2033)
    ("ord"	"\\trprime"	#X2034)
    ("ord"	"\\backprime"	#X2035)
    ("ord"	"\\backdprime"	#X2036)
    ("ord"	"\\backtrprime"	#X2037)
    ("ord"	"\\caretinsert"	#X2038)
    ("ord"	"\\Exclam"	#X203C)
    ("bin"	"\\tieconcat"	#X2040)
    ("ord"	"\\hyphenbullet"	#X2043)
    ("bin"	"\\fracslash"	#X2044)
    ("ord"	"\\Question"	#X2047)
    ("rel"	"\\closure"	#X2050)
    ("ord"	"\\qprime"	#X2057)
    ("ord"	"\\euro"	#X20AC)
    ("accent"	"\\leftharpoonaccent"	#X20D0)
    ("accent"	"\\rightharpoonaccent"	#X20D1)
    ("accent"	"\\vertoverlay"	#X20D2)
    ("accent"	"\\overleftarrow"	#X20D6)
    ("accent"	"\\vec"	#X20D7)
    ("accent"	"\\dddot"	#X20DB)
    ("accent"	"\\ddddot"	#X20DC)
    ("ord"	"\\enclosecircle"	#X20DD)
    ("ord"	"\\enclosesquare"	#X20DE)
    ("ord"	"\\enclosediamond"	#X20DF)
    ("accent"	"\\overleftrightarrow"	#X20E1)
    ("ord"	"\\enclosetriangle"	#X20E4)
    ("accent"	"\\annuity"	#X20E7)
    ("accent"	"\\threeunderdot"	#X20E8)
    ("accent"	"\\widebridgeabove"	#X20E9)
    ("accent"	"\\underrightharpoondown"	#X20EC)
    ("accent"	"\\underleftharpoondown"	#X20ED)
    ("accent"	"\\underleftarrow"	#X20EE)
    ("accent"	"\\underrightarrow"	#X20EF)
    ("accent"	"\\asteraccent"	#X20F0)
    ("alpha"	"\\BbbC"	#X2102)
    ("ord"	"\\Eulerconst"	#X2107)
    ("alpha"	"\\mscrg"	#X210A)
    ("alpha"	"\\mscrH"	#X210B)
    ("alpha"	"\\mfrakH"	#X210C)
    ("alpha"	"\\BbbH"	#X210D)
    ("ord"	"\\Planckconst"	#X210E)
    ("alpha"	"\\hslash"	#X210F)
    ("alpha"	"\\mscrI"	#X2110)
    ("alpha"	"\\Im"	#X2111)
    ("alpha"	"\\mscrL"	#X2112)
    ("alpha"	"\\ell"	#X2113)
    ("alpha"	"\\BbbN"	#X2115)
    ("alpha"	"\\wp"	#X2118)
    ("alpha"	"\\BbbP"	#X2119)
    ("alpha"	"\\BbbQ"	#X211A)
    ("alpha"	"\\mscrR"	#X211B)
    ("alpha"	"\\Re"	#X211C)
    ("alpha"	"\\BbbR"	#X211D)
    ("alpha"	"\\BbbZ"	#X2124)
    ("ord"	"\\mho"	#X2127)
    ("alpha"	"\\mfrakZ"	#X2128)
    ("alpha"	"\\turnediota"	#X2129)
    ("alpha"	"\\Angstrom"	#X212B)
    ("alpha"	"\\mscrB"	#X212C)
    ("alpha"	"\\mfrakC"	#X212D)
    ("alpha"	"\\mscre"	#X212F)
    ("alpha"	"\\mscrE"	#X2130)
    ("alpha"	"\\mscrF"	#X2131)
    ("ord"	"\\Finv"	#X2132)
    ("alpha"	"\\mscrM"	#X2133)
    ("alpha"	"\\mscro"	#X2134)
    ("alpha"	"\\aleph"	#X2135)
    ("alpha"	"\\beth"	#X2136)
    ("alpha"	"\\gimel"	#X2137)
    ("alpha"	"\\daleth"	#X2138)
    ("ord"	"\\Bbbpi"	#X213C)
    ("alpha"	"\\Bbbgamma"	#X213D)
    ("alpha"	"\\BbbGamma"	#X213E)
    ("alpha"	"\\BbbPi"	#X213F)
    ("op"	"\\Bbbsum"	#X2140)
    ("ord"	"\\Game"	#X2141)
    ("ord"	"\\sansLturned"	#X2142)
    ("ord"	"\\sansLmirrored"	#X2143)
    ("ord"	"\\Yup"	#X2144)
    ("ord"	"\\mitBbbD"	#X2145)
    ("ord"	"\\mitBbbd"	#X2146)
    ("ord"	"\\mitBbbe"	#X2147)
    ("ord"	"\\mitBbbi"	#X2148)
    ("ord"	"\\mitBbbj"	#X2149)
    ("ord"	"\\PropertyLine"	#X214A)
    ("bin"	"\\upand"	#X214B)
    ("rel"	"\\leftarrow"	#X2190)
    ("rel"	"\\uparrow"	#X2191)
    ("rel"	"\\rightarrow"	#X2192)
    ("rel"	"\\downarrow"	#X2193)
    ("rel"	"\\leftrightarrow"	#X2194)
    ("rel"	"\\updownarrow"	#X2195)
    ("rel"	"\\nwarrow"	#X2196)
    ("rel"	"\\nearrow"	#X2197)
    ("rel"	"\\searrow"	#X2198)
    ("rel"	"\\swarrow"	#X2199)
    ("rel"	"\\nleftarrow"	#X219A)
    ("rel"	"\\nrightarrow"	#X219B)
    ("rel"	"\\leftwavearrow"	#X219C)
    ("rel"	"\\rightwavearrow"	#X219D)
    ("rel"	"\\twoheadleftarrow"	#X219E)
    ("rel"	"\\twoheaduparrow"	#X219F)
    ("rel"	"\\twoheadrightarrow"	#X21A0)
    ("rel"	"\\twoheaddownarrow"	#X21A1)
    ("rel"	"\\leftarrowtail"	#X21A2)
    ("rel"	"\\rightarrowtail"	#X21A3)
    ("rel"	"\\mapsfrom"	#X21A4)
    ("rel"	"\\mapsup"	#X21A5)
    ("rel"	"\\mapsto"	#X21A6)
    ("rel"	"\\mapsdown"	#X21A7)
    ("ord"	"\\updownarrowbar"	#X21A8)
    ("rel"	"\\hookleftarrow"	#X21A9)
    ("rel"	"\\hookrightarrow"	#X21AA)
    ("rel"	"\\looparrowleft"	#X21AB)
    ("rel"	"\\looparrowright"	#X21AC)
    ("rel"	"\\leftrightsquigarrow"	#X21AD)
    ("rel"	"\\nleftrightarrow"	#X21AE)
    ("rel"	"\\downzigzagarrow"	#X21AF)
    ("rel"	"\\Lsh"	#X21B0)
    ("rel"	"\\Rsh"	#X21B1)
    ("rel"	"\\Ldsh"	#X21B2)
    ("rel"	"\\Rdsh"	#X21B3)
    ("ord"	"\\linefeed"	#X21B4)
    ("ord"	"\\carriagereturn"	#X21B5)
    ("rel"	"\\curvearrowleft"	#X21B6)
    ("rel"	"\\curvearrowright"	#X21B7)
    ("ord"	"\\barovernorthwestarrow"	#X21B8)
    ("ord"	"\\barleftarrowrightarrowbar"	#X21B9)
    ("ord"	"\\acwopencirclearrow"	#X21BA)
    ("ord"	"\\cwopencirclearrow"	#X21BB)
    ("rel"	"\\leftharpoonup"	#X21BC)
    ("rel"	"\\leftharpoondown"	#X21BD)
    ("rel"	"\\upharpoonright"	#X21BE)
    ("rel"	"\\upharpoonleft"	#X21BF)
    ("rel"	"\\rightharpoonup"	#X21C0)
    ("rel"	"\\rightharpoondown"	#X21C1)
    ("rel"	"\\downharpoonright"	#X21C2)
    ("rel"	"\\downharpoonleft"	#X21C3)
    ("rel"	"\\rightleftarrows"	#X21C4)
    ("rel"	"\\updownarrows"	#X21C5)
    ("rel"	"\\leftrightarrows"	#X21C6)
    ("rel"	"\\leftleftarrows"	#X21C7)
    ("rel"	"\\upuparrows"	#X21C8)
    ("rel"	"\\rightrightarrows"	#X21C9)
    ("rel"	"\\downdownarrows"	#X21CA)
    ("rel"	"\\leftrightharpoons"	#X21CB)
    ("rel"	"\\rightleftharpoons"	#X21CC)
    ("rel"	"\\nLeftarrow"	#X21CD)
    ("rel"	"\\nLeftrightarrow"	#X21CE)
    ("rel"	"\\nRightarrow"	#X21CF)
    ("rel"	"\\Leftarrow"	#X21D0)
    ("rel"	"\\Uparrow"	#X21D1)
    ("rel"	"\\Rightarrow"	#X21D2)
    ("rel"	"\\Downarrow"	#X21D3)
    ("rel"	"\\Leftrightarrow"	#X21D4)
    ("rel"	"\\Updownarrow"	#X21D5)
    ("rel"	"\\Nwarrow"	#X21D6)
    ("rel"	"\\Nearrow"	#X21D7)
    ("rel"	"\\Searrow"	#X21D8)
    ("rel"	"\\Swarrow"	#X21D9)
    ("rel"	"\\Lleftarrow"	#X21DA)
    ("rel"	"\\Rrightarrow"	#X21DB)
    ("rel"	"\\leftsquigarrow"	#X21DC)
    ("rel"	"\\rightsquigarrow"	#X21DD)
    ("ord"	"\\nHuparrow"	#X21DE)
    ("ord"	"\\nHdownarrow"	#X21DF)
    ("ord"	"\\leftdasharrow"	#X21E0)
    ("ord"	"\\updasharrow"	#X21E1)
    ("ord"	"\\rightdasharrow"	#X21E2)
    ("ord"	"\\downdasharrow"	#X21E3)
    ("rel"	"\\barleftarrow"	#X21E4)
    ("rel"	"\\rightarrowbar"	#X21E5)
    ("ord"	"\\leftwhitearrow"	#X21E6)
    ("ord"	"\\upwhitearrow"	#X21E7)
    ("ord"	"\\rightwhitearrow"	#X21E8)
    ("ord"	"\\downwhitearrow"	#X21E9)
    ("ord"	"\\whitearrowupfrombar"	#X21EA)
    ("rel"	"\\circleonrightarrow"	#X21F4)
    ("rel"	"\\downuparrows"	#X21F5)
    ("rel"	"\\rightthreearrows"	#X21F6)
    ("rel"	"\\nvleftarrow"	#X21F7)
    ("rel"	"\\nvrightarrow"	#X21F8)
    ("rel"	"\\nvleftrightarrow"	#X21F9)
    ("rel"	"\\nVleftarrow"	#X21FA)
    ("rel"	"\\nVrightarrow"	#X21FB)
    ("rel"	"\\nVleftrightarrow"	#X21FC)
    ("rel"	"\\leftarrowtriangle"	#X21FD)
    ("rel"	"\\rightarrowtriangle"	#X21FE)
    ("rel"	"\\leftrightarrowtriangle"	#X21FF)
    ("ord"	"\\forall"	#X2200)
    ("ord"	"\\complement"	#X2201)
    ("ord"	"\\partial"	#X2202)
    ("ord"	"\\exists"	#X2203)
    ("ord"	"\\nexists"	#X2204)
    ("ord"	"\\varnothing"	#X2205)
    ("ord"	"\\increment"	#X2206)
    ("ord"	"\\nabla"	#X2207)
    ("rel"	"\\in"	#X2208)
    ("rel"	"\\notin"	#X2209)
    ("rel"	"\\smallin"	#X220A)
    ("rel"	"\\ni"	#X220B)
    ("rel"	"\\nni"	#X220C)
    ("rel"	"\\smallni"	#X220D)
    ("ord"	"\\QED"	#X220E)
    ("op"	"\\prod"	#X220F)
    ("op"	"\\coprod"	#X2210)
    ("op"	"\\sum"	#X2211)
    ("bin"	"\\minus"	#X2212)
    ("bin"	"\\mp"	#X2213)
    ("bin"	"\\dotplus"	#X2214)
    ("bin"	"\\divslash"	#X2215)
    ("bin"	"\\smallsetminus"	#X2216)
    ("bin"	"\\ast"	#X2217)
    ("bin"	"\\vysmwhtcircle"	#X2218)
    ("bin"	"\\vysmblkcircle"	#X2219)
    ("open"	"\\sqrt"	#X221A)
    ("open"	"\\cuberoot"	#X221B)
    ("open"	"\\fourthroot"	#X221C)
    ("rel"	"\\propto"	#X221D)
    ("ord"	"\\infty"	#X221E)
    ("ord"	"\\rightangle"	#X221F)
    ("ord"	"\\angle"	#X2220)
    ("ord"	"\\measuredangle"	#X2221)
    ("ord"	"\\sphericalangle"	#X2222)
    ("rel"	"\\mid"	#X2223)
    ("rel"	"\\nmid"	#X2224)
    ("rel"	"\\parallel"	#X2225)
    ("rel"	"\\nparallel"	#X2226)
    ("bin"	"\\wedge"	#X2227)
    ("bin"	"\\vee"	#X2228)
    ("bin"	"\\cap"	#X2229)
    ("bin"	"\\cup"	#X222A)
    ("op"	"\\int"	#X222B)
    ("op"	"\\iint"	#X222C)
    ("op"	"\\iiint"	#X222D)
    ("op"	"\\oint"	#X222E)
    ("op"	"\\oiint"	#X222F)
    ("op"	"\\oiiint"	#X2230)
    ("op"	"\\intclockwise"	#X2231)
    ("op"	"\\varointclockwise"	#X2232)
    ("op"	"\\ointctrclockwise"	#X2233)
    ("ord"	"\\therefore"	#X2234)
    ("ord"	"\\because"	#X2235)
    ("rel"	"\\mathratio"	#X2236)
    ("rel"	"\\Colon"	#X2237)
    ("bin"	"\\dotminus"	#X2238)
    ("rel"	"\\dashcolon"	#X2239)
    ("rel"	"\\dotsminusdots"	#X223A)
    ("rel"	"\\kernelcontraction"	#X223B)
    ("rel"	"\\sim"	#X223C)
    ("rel"	"\\backsim"	#X223D)
    ("bin"	"\\invlazys"	#X223E)
    ("ord"	"\\sinewave"	#X223F)
    ("bin"	"\\wr"	#X2240)
    ("rel"	"\\nsim"	#X2241)
    ("rel"	"\\eqsim"	#X2242)
    ("rel"	"\\simeq"	#X2243)
    ("rel"	"\\nsime"	#X2244)
    ("rel"	"\\cong"	#X2245)
    ("rel"	"\\simneqq"	#X2246)
    ("rel"	"\\ncong"	#X2247)
    ("rel"	"\\approx"	#X2248)
    ("rel"	"\\napprox"	#X2249)
    ("rel"	"\\approxeq"	#X224A)
    ("rel"	"\\approxident"	#X224B)
    ("rel"	"\\backcong"	#X224C)
    ("rel"	"\\asymp"	#X224D)
    ("rel"	"\\Bumpeq"	#X224E)
    ("rel"	"\\bumpeq"	#X224F)
    ("rel"	"\\doteq"	#X2250)
    ("rel"	"\\Doteq"	#X2251)
    ("rel"	"\\fallingdotseq"	#X2252)
    ("rel"	"\\risingdotseq"	#X2253)
    ("rel"	"\\coloneq"	#X2254)
    ("rel"	"\\eqcolon"	#X2255)
    ("rel"	"\\eqcirc"	#X2256)
    ("rel"	"\\circeq"	#X2257)
    ("rel"	"\\arceq"	#X2258)
    ("rel"	"\\wedgeq"	#X2259)
    ("rel"	"\\veeeq"	#X225A)
    ("rel"	"\\stareq"	#X225B)
    ("rel"	"\\triangleq"	#X225C)
    ("rel"	"\\eqdef"	#X225D)
    ("rel"	"\\measeq"	#X225E)
    ("rel"	"\\questeq"	#X225F)
    ("rel"	"\\ne"	#X2260)
    ("rel"	"\\equiv"	#X2261)
    ("rel"	"\\nequiv"	#X2262)
    ("rel"	"\\Equiv"	#X2263)
    ("rel"	"\\leq"	#X2264)
    ("rel"	"\\geq"	#X2265)
    ("rel"	"\\leqq"	#X2266)
    ("rel"	"\\geqq"	#X2267)
    ("rel"	"\\lneqq"	#X2268)
    ("rel"	"\\gneqq"	#X2269)
    ("rel"	"\\ll"	#X226A)
    ("rel"	"\\gg"	#X226B)
    ("rel"	"\\between"	#X226C)
    ("rel"	"\\nasymp"	#X226D)
    ("rel"	"\\nless"	#X226E)
    ("rel"	"\\ngtr"	#X226F)
    ("rel"	"\\nleq"	#X2270)
    ("rel"	"\\ngeq"	#X2271)
    ("rel"	"\\lesssim"	#X2272)
    ("rel"	"\\gtrsim"	#X2273)
    ("rel"	"\\nlesssim"	#X2274)
    ("rel"	"\\ngtrsim"	#X2275)
    ("rel"	"\\lessgtr"	#X2276)
    ("rel"	"\\gtrless"	#X2277)
    ("rel"	"\\nlessgtr"	#X2278)
    ("rel"	"\\ngtrless"	#X2279)
    ("rel"	"\\prec"	#X227A)
    ("rel"	"\\succ"	#X227B)
    ("rel"	"\\preccurlyeq"	#X227C)
    ("rel"	"\\succcurlyeq"	#X227D)
    ("rel"	"\\precsim"	#X227E)
    ("rel"	"\\succsim"	#X227F)
    ("rel"	"\\nprec"	#X2280)
    ("rel"	"\\nsucc"	#X2281)
    ("rel"	"\\subset"	#X2282)
    ("rel"	"\\supset"	#X2283)
    ("rel"	"\\nsubset"	#X2284)
    ("rel"	"\\nsupset"	#X2285)
    ("rel"	"\\subseteq"	#X2286)
    ("rel"	"\\supseteq"	#X2287)
    ("rel"	"\\nsubseteq"	#X2288)
    ("rel"	"\\nsupseteq"	#X2289)
    ("rel"	"\\subsetneq"	#X228A)
    ("rel"	"\\supsetneq"	#X228B)
    ("bin"	"\\cupleftarrow"	#X228C)
    ("bin"	"\\cupdot"	#X228D)
    ("bin"	"\\uplus"	#X228E)
    ("rel"	"\\sqsubset"	#X228F)
    ("rel"	"\\sqsupset"	#X2290)
    ("rel"	"\\sqsubseteq"	#X2291)
    ("rel"	"\\sqsupseteq"	#X2292)
    ("bin"	"\\sqcap"	#X2293)
    ("bin"	"\\sqcup"	#X2294)
    ("bin"	"\\oplus"	#X2295)
    ("bin"	"\\ominus"	#X2296)
    ("bin"	"\\otimes"	#X2297)
    ("bin"	"\\oslash"	#X2298)
    ("bin"	"\\odot"	#X2299)
    ("bin"	"\\circledcirc"	#X229A)
    ("bin"	"\\circledast"	#X229B)
    ("bin"	"\\circledequal"	#X229C)
    ("bin"	"\\circleddash"	#X229D)
    ("bin"	"\\boxplus"	#X229E)
    ("bin"	"\\boxminus"	#X229F)
    ("bin"	"\\boxtimes"	#X22A0)
    ("bin"	"\\boxdot"	#X22A1)
    ("rel"	"\\vdash"	#X22A2)
    ("rel"	"\\dashv"	#X22A3)
    ("ord"	"\\top"	#X22A4)
    ("ord"	"\\bot"	#X22A5)
    ("rel"	"\\assert"	#X22A6)
    ("rel"	"\\models"	#X22A7)
    ("rel"	"\\vDash"	#X22A8)
    ("rel"	"\\Vdash"	#X22A9)
    ("rel"	"\\Vvdash"	#X22AA)
    ("rel"	"\\VDash"	#X22AB)
    ("rel"	"\\nvdash"	#X22AC)
    ("rel"	"\\nvDash"	#X22AD)
    ("rel"	"\\nVdash"	#X22AE)
    ("rel"	"\\nVDash"	#X22AF)
    ("rel"	"\\prurel"	#X22B0)
    ("rel"	"\\scurel"	#X22B1)
    ("rel"	"\\vartriangleleft"	#X22B2)
    ("rel"	"\\vartriangleright"	#X22B3)
    ("rel"	"\\trianglelefteq"	#X22B4)
    ("rel"	"\\trianglerighteq"	#X22B5)
    ("rel"	"\\origof"	#X22B6)
    ("rel"	"\\imageof"	#X22B7)
    ("rel"	"\\multimap"	#X22B8)
    ("ord"	"\\hermitmatrix"	#X22B9)
    ("bin"	"\\intercal"	#X22BA)
    ("bin"	"\\veebar"	#X22BB)
    ("bin"	"\\barwedge"	#X22BC)
    ("bin"	"\\barvee"	#X22BD)
    ("ord"	"\\measuredrightangle"	#X22BE)
    ("ord"	"\\varlrtriangle"	#X22BF)
    ("op"	"\\bigwedge"	#X22C0)
    ("op"	"\\bigvee"	#X22C1)
    ("op"	"\\bigcap"	#X22C2)
    ("op"	"\\bigcup"	#X22C3)
    ("bin"	"\\smwhtdiamond"	#X22C4)
    ("bin"	"\\cdot"	#X22C5)
    ("bin"	"\\star"	#X22C6)
    ("bin"	"\\divideontimes"	#X22C7)
    ("rel"	"\\bowtie"	#X22C8)
    ("bin"	"\\ltimes"	#X22C9)
    ("bin"	"\\rtimes"	#X22CA)
    ("bin"	"\\leftthreetimes"	#X22CB)
    ("bin"	"\\rightthreetimes"	#X22CC)
    ("rel"	"\\backsimeq"	#X22CD)
    ("bin"	"\\curlyvee"	#X22CE)
    ("bin"	"\\curlywedge"	#X22CF)
    ("rel"	"\\Subset"	#X22D0)
    ("rel"	"\\Supset"	#X22D1)
    ("bin"	"\\Cap"	#X22D2)
    ("bin"	"\\Cup"	#X22D3)
    ("rel"	"\\pitchfork"	#X22D4)
    ("rel"	"\\equalparallel"	#X22D5)
    ("rel"	"\\lessdot"	#X22D6)
    ("rel"	"\\gtrdot"	#X22D7)
    ("rel"	"\\lll"	#X22D8)
    ("rel"	"\\ggg"	#X22D9)
    ("rel"	"\\lesseqgtr"	#X22DA)
    ("rel"	"\\gtreqless"	#X22DB)
    ("rel"	"\\eqless"	#X22DC)
    ("rel"	"\\eqgtr"	#X22DD)
    ("rel"	"\\curlyeqprec"	#X22DE)
    ("rel"	"\\curlyeqsucc"	#X22DF)
    ("rel"	"\\npreccurlyeq"	#X22E0)
    ("rel"	"\\nsucccurlyeq"	#X22E1)
    ("rel"	"\\nsqsubseteq"	#X22E2)
    ("rel"	"\\nsqsupseteq"	#X22E3)
    ("rel"	"\\sqsubsetneq"	#X22E4)
    ("rel"	"\\sqsupsetneq"	#X22E5)
    ("rel"	"\\lnsim"	#X22E6)
    ("rel"	"\\gnsim"	#X22E7)
    ("rel"	"\\precnsim"	#X22E8)
    ("rel"	"\\succnsim"	#X22E9)
    ("rel"	"\\ntriangleleft"	#X22EA)
    ("rel"	"\\ntriangleright"	#X22EB)
    ("rel"	"\\ntrianglelefteq"	#X22EC)
    ("rel"	"\\ntrianglerighteq"	#X22ED)
    ("rel"	"\\vdots"	#X22EE)
    ("ord"	"\\unicodecdots"	#X22EF)
    ("rel"	"\\adots"	#X22F0)
    ("rel"	"\\ddots"	#X22F1)
    ("rel"	"\\disin"	#X22F2)
    ("rel"	"\\varisins"	#X22F3)
    ("rel"	"\\isins"	#X22F4)
    ("rel"	"\\isindot"	#X22F5)
    ("rel"	"\\varisinobar"	#X22F6)
    ("rel"	"\\isinobar"	#X22F7)
    ("rel"	"\\isinvb"	#X22F8)
    ("rel"	"\\isinE"	#X22F9)
    ("rel"	"\\nisd"	#X22FA)
    ("rel"	"\\varnis"	#X22FB)
    ("rel"	"\\nis"	#X22FC)
    ("rel"	"\\varniobar"	#X22FD)
    ("rel"	"\\niobar"	#X22FE)
    ("rel"	"\\bagmember"	#X22FF)
    ("ord"	"\\diameter"	#X2300)
    ("ord"	"\\house"	#X2302)
    ("bin"	"\\varbarwedge"	#X2305)
    ("bin"	"\\vardoublebarwedge"	#X2306)
    ("open"	"\\lceil"	#X2308)
    ("close"	"\\rceil"	#X2309)
    ("open"	"\\lfloor"	#X230A)
    ("close"	"\\rfloor"	#X230B)
    ("ord"	"\\invnot"	#X2310)
    ("ord"	"\\sqlozenge"	#X2311)
    ("ord"	"\\profline"	#X2312)
    ("ord"	"\\profsurf"	#X2313)
    ("ord"	"\\viewdata"	#X2317)
    ("ord"	"\\turnednot"	#X2319)
    ("open"	"\\ulcorner"	#X231C)
    ("close"	"\\urcorner"	#X231D)
    ("open"	"\\llcorner"	#X231E)
    ("close"	"\\lrcorner"	#X231F)
    ("ord"	"\\inttop"	#X2320)
    ("ord"	"\\intbottom"	#X2321)
    ("rel"	"\\frown"	#X2322)
    ("rel"	"\\smile"	#X2323)
    ("ord"	"\\varhexagonlrbonds"	#X232C)
    ("ord"	"\\conictaper"	#X2332)
    ("ord"	"\\topbot"	#X2336)
    ("bin"	"\\obar"	#X233D)
    ("rel"	"\\APLnotslash"	#X233F)
    ("ord"	"\\APLnotbackslash"	#X2340)
    ("ord"	"\\APLboxupcaret"	#X2353)
    ("ord"	"\\APLboxquestion"	#X2370)
    ("ord"	"\\rangledownzigzagarrow"	#X237C)
    ("ord"	"\\hexagon"	#X2394)
    ("ord"	"\\lparenuend"	#X239B)
    ("ord"	"\\lparenextender"	#X239C)
    ("ord"	"\\lparenlend"	#X239D)
    ("ord"	"\\rparenuend"	#X239E)
    ("ord"	"\\rparenextender"	#X239F)
    ("ord"	"\\rparenlend"	#X23A0)
    ("ord"	"\\lbrackuend"	#X23A1)
    ("ord"	"\\lbrackextender"	#X23A2)
    ("ord"	"\\lbracklend"	#X23A3)
    ("ord"	"\\rbrackuend"	#X23A4)
    ("ord"	"\\rbrackextender"	#X23A5)
    ("ord"	"\\rbracklend"	#X23A6)
    ("ord"	"\\lbraceuend"	#X23A7)
    ("ord"	"\\lbracemid"	#X23A8)
    ("ord"	"\\lbracelend"	#X23A9)
    ("ord"	"\\vbraceextender"	#X23AA)
    ("ord"	"\\rbraceuend"	#X23AB)
    ("ord"	"\\rbracemid"	#X23AC)
    ("ord"	"\\rbracelend"	#X23AD)
    ("ord"	"\\intextender"	#X23AE)
    ("ord"	"\\harrowextender"	#X23AF)
    ("ord"	"\\lmoustache"	#X23B0)
    ("ord"	"\\rmoustache"	#X23B1)
    ("ord"	"\\sumtop"	#X23B2)
    ("ord"	"\\sumbottom"	#X23B3)
    ("over"	"\\overbracket"	#X23B4)
    ("under"	"\\underbracket"	#X23B5)
    ("ord"	"\\bbrktbrk"	#X23B6)
    ("ord"	"\\sqrtbottom"	#X23B7)
    ("ord"	"\\lvboxline"	#X23B8)
    ("ord"	"\\rvboxline"	#X23B9)
    ("ord"	"\\varcarriagereturn"	#X23CE)
    ("over"	"\\overparen"	#X23DC)
    ("under"	"\\underparen"	#X23DD)
    ("over"	"\\overbrace"	#X23DE)
    ("under"	"\\underbrace"	#X23DF)
    ("ord"	"\\obrbrak"	#X23E0)
    ("ord"	"\\ubrbrak"	#X23E1)
    ("ord"	"\\trapezium"	#X23E2)
    ("ord"	"\\benzenr"	#X23E3)
    ("ord"	"\\strns"	#X23E4)
    ("ord"	"\\fltns"	#X23E5)
    ("ord"	"\\accurrent"	#X23E6)
    ("ord"	"\\elinters"	#X23E7)
    ("ord"	"\\bdtriplevdash"	#X2506)
    ("ord"	"\\blockuphalf"	#X2580)
    ("ord"	"\\blocklowhalf"	#X2584)
    ("ord"	"\\blockfull"	#X2588)
    ("ord"	"\\blocklefthalf"	#X258C)
    ("ord"	"\\blockrighthalf"	#X2590)
    ("ord"	"\\blockqtrshaded"	#X2591)
    ("ord"	"\\blockhalfshaded"	#X2592)
    ("ord"	"\\blockthreeqtrshaded"	#X2593)
    ("ord"	"\\mdlgblksquare"	#X25A0)
    ("ord"	"\\mdlgwhtsquare"	#X25A1)
    ("ord"	"\\squoval"	#X25A2)
    ("ord"	"\\blackinwhitesquare"	#X25A3)
    ("ord"	"\\squarehfill"	#X25A4)
    ("ord"	"\\squarevfill"	#X25A5)
    ("ord"	"\\squarehvfill"	#X25A6)
    ("ord"	"\\squarenwsefill"	#X25A7)
    ("ord"	"\\squareneswfill"	#X25A8)
    ("ord"	"\\squarecrossfill"	#X25A9)
    ("ord"	"\\smblksquare"	#X25AA)
    ("ord"	"\\smwhtsquare"	#X25AB)
    ("ord"	"\\hrectangleblack"	#X25AC)
    ("ord"	"\\hrectangle"	#X25AD)
    ("ord"	"\\vrectangleblack"	#X25AE)
    ("ord"	"\\vrectangle"	#X25AF)
    ("ord"	"\\parallelogramblack"	#X25B0)
    ("ord"	"\\parallelogram"	#X25B1)
    ("ord"	"\\bigblacktriangleup"	#X25B2)
    ("bin"	"\\bigtriangleup"	#X25B3)
    ("ord"	"\\blacktriangle"	#X25B4)
    ("rel"	"\\vartriangle"	#X25B5)
    ("ord"	"\\blacktriangleright"	#X25B6)
    ("bin"	"\\triangleright"	#X25B7)
    ("ord"	"\\smallblacktriangleright "	#X25B8)
    ("ord"	"\\smalltriangleright"	#X25B9)
    ("ord"	"\\blackpointerright"	#X25BA)
    ("ord"	"\\whitepointerright"	#X25BB)
    ("ord"	"\\bigblacktriangledown"	#X25BC)
    ("ord"	"\\bigtriangledown"	#X25BD)
    ("ord"	"\\blacktriangledown"	#X25BE)
    ("ord"	"\\triangledown"	#X25BF)
    ("ord"	"\\blacktriangleleft"	#X25C0)
    ("bin"	"\\triangleleft"	#X25C1)
    ("ord"	"\\smallblacktriangleleft"	#X25C2)
    ("ord"	"\\smalltriangleleft"	#X25C3)
    ("ord"	"\\blackpointerleft"	#X25C4)
    ("ord"	"\\whitepointerleft"	#X25C5)
    ("ord"	"\\mdlgblkdiamond"	#X25C6)
    ("ord"	"\\mdlgwhtdiamond"	#X25C7)
    ("ord"	"\\blackinwhitediamond"	#X25C8)
    ("ord"	"\\fisheye"	#X25C9)
    ("ord"	"\\mdlgwhtlozenge"	#X25CA)
    ("bin"	"\\mdlgwhtcircle"	#X25CB)
    ("ord"	"\\dottedcircle"	#X25CC)
    ("ord"	"\\circlevertfill"	#X25CD)
    ("ord"	"\\bullseye"	#X25CE)
    ("ord"	"\\mdlgblkcircle"	#X25CF)
    ("ord"	"\\circlelefthalfblack"	#X25D0)
    ("ord"	"\\circlerighthalfblack"	#X25D1)
    ("ord"	"\\circlebottomhalfblack"	#X25D2)
    ("ord"	"\\circletophalfblack"	#X25D3)
    ("ord"	"\\circleurquadblack"	#X25D4)
    ("ord"	"\\blackcircleulquadwhite"	#X25D5)
    ("ord"	"\\blacklefthalfcircle"	#X25D6)
    ("ord"	"\\blackrighthalfcircle"	#X25D7)
    ("ord"	"\\inversebullet"	#X25D8)
    ("ord"	"\\inversewhitecircle"	#X25D9)
    ("ord"	"\\invwhiteupperhalfcircle "	#X25DA)
    ("ord"	"\\invwhitelowerhalfcircle "	#X25DB)
    ("ord"	"\\ularc"	#X25DC)
    ("ord"	"\\urarc"	#X25DD)
    ("ord"	"\\lrarc"	#X25DE)
    ("ord"	"\\llarc"	#X25DF)
    ("ord"	"\\topsemicircle"	#X25E0)
    ("ord"	"\\botsemicircle"	#X25E1)
    ("ord"	"\\lrblacktriangle"	#X25E2)
    ("ord"	"\\llblacktriangle"	#X25E3)
    ("ord"	"\\ulblacktriangle"	#X25E4)
    ("ord"	"\\urblacktriangle"	#X25E5)
    ("ord"	"\\smwhtcircle"	#X25E6)
    ("ord"	"\\squareleftblack"	#X25E7)
    ("ord"	"\\squarerightblack"	#X25E8)
    ("ord"	"\\squareulblack"	#X25E9)
    ("ord"	"\\squarelrblack"	#X25EA)
    ("bin"	"\\boxbar"	#X25EB)
    ("ord"	"\\trianglecdot"	#X25EC)
    ("ord"	"\\triangleleftblack"	#X25ED)
    ("ord"	"\\trianglerightblack"	#X25EE)
    ("ord"	"\\lgwhtcircle"	#X25EF)
    ("ord"	"\\squareulquad"	#X25F0)
    ("ord"	"\\squarellquad"	#X25F1)
    ("ord"	"\\squarelrquad"	#X25F2)
    ("ord"	"\\squareurquad"	#X25F3)
    ("ord"	"\\circleulquad"	#X25F4)
    ("ord"	"\\circlellquad"	#X25F5)
    ("ord"	"\\circlelrquad"	#X25F6)
    ("ord"	"\\circleurquad"	#X25F7)
    ("ord"	"\\ultriangle"	#X25F8)
    ("ord"	"\\urtriangle"	#X25F9)
    ("ord"	"\\lltriangle"	#X25FA)
    ("ord"	"\\mdwhtsquare"	#X25FB)
    ("ord"	"\\mdblksquare"	#X25FC)
    ("ord"	"\\mdsmwhtsquare"	#X25FD)
    ("ord"	"\\mdsmblksquare"	#X25FE)
    ("ord"	"\\lrtriangle"	#X25FF)
    ("ord"	"\\bigstar"	#X2605)
    ("ord"	"\\bigwhitestar"	#X2606)
    ("ord"	"\\astrosun"	#X2609)
    ("ord"	"\\danger"	#X2621)
    ("ord"	"\\blacksmiley"	#X263B)
    ("ord"	"\\sun"	#X263C)
    ("ord"	"\\rightmoon"	#X263D)
    ("ord"	"\\leftmoon"	#X263E)
    ("ord"	"\\female"	#X2640)
    ("ord"	"\\male"	#X2642)
    ("ord"	"\\spadesuit"	#X2660)
    ("ord"	"\\heartsuit"	#X2661)
    ("ord"	"\\diamondsuit"	#X2662)
    ("ord"	"\\clubsuit"	#X2663)
    ("ord"	"\\varspadesuit"	#X2664)
    ("ord"	"\\varheartsuit"	#X2665)
    ("ord"	"\\vardiamondsuit"	#X2666)
    ("ord"	"\\varclubsuit"	#X2667)
    ("ord"	"\\quarternote"	#X2669)
    ("ord"	"\\eighthnote"	#X266A)
    ("ord"	"\\twonotes"	#X266B)
    ("ord"	"\\flat"	#X266D)
    ("ord"	"\\natural"	#X266E)
    ("ord"	"\\sharp"	#X266F)
    ("ord"	"\\acidfree"	#X267E)
    ("ord"	"\\dicei"	#X2680)
    ("ord"	"\\diceii"	#X2681)
    ("ord"	"\\diceiii"	#X2682)
    ("ord"	"\\diceiv"	#X2683)
    ("ord"	"\\dicev"	#X2684)
    ("ord"	"\\dicevi"	#X2685)
    ("ord"	"\\circledrightdot"	#X2686)
    ("ord"	"\\circledtwodots"	#X2687)
    ("ord"	"\\blackcircledrightdot"	#X2688)
    ("ord"	"\\blackcircledtwodots"	#X2689)
    ("ord"	"\\Hermaphrodite"	#X26A5)
    ("ord"	"\\mdwhtcircle"	#X26AA)
    ("ord"	"\\mdblkcircle"	#X26AB)
    ("ord"	"\\mdsmwhtcircle"	#X26AC)
    ("ord"	"\\neuter"	#X26B2)
    ("ord"	"\\checkmark"	#X2713)
    ("ord"	"\\maltese"	#X2720)
    ("ord"	"\\circledstar"	#X272A)
    ("ord"	"\\varstar"	#X2736)
    ("ord"	"\\dingasterisk"	#X273D)
    ("open"	"\\lbrbrak"	#X2772)
    ("close"	"\\rbrbrak"	#X2773)
    ("ord"	"\\draftingarrow"	#X279B)
    ("ord"	"\\threedangle"	#X27C0)
    ("ord"	"\\whiteinwhitetriangle"	#X27C1)
    ("rel"	"\\perp"	#X27C2)
    ("ord"	"\\subsetcirc"	#X27C3)
    ("ord"	"\\supsetcirc"	#X27C4)
    ("open"	"\\lbag"	#X27C5)
    ("close"	"\\rbag"	#X27C6)
    ("bin"	"\\veedot"	#X27C7)
    ("rel"	"\\bsolhsub"	#X27C8)
    ("rel"	"\\suphsol"	#X27C9)
    ("open"	"\\longdivision"	#X27CC)
    ("ord"	"\\diamondcdot"	#X27D0)
    ("bin"	"\\wedgedot"	#X27D1)
    ("rel"	"\\upin"	#X27D2)
    ("rel"	"\\pullback"	#X27D3)
    ("rel"	"\\pushout"	#X27D4)
    ("op"	"\\leftouterjoin"	#X27D5)
    ("op"	"\\rightouterjoin"	#X27D6)
    ("op"	"\\fullouterjoin"	#X27D7)
    ("op"	"\\bigbot"	#X27D8)
    ("op"	"\\bigtop"	#X27D9)
    ("rel"	"\\DashVDash"	#X27DA)
    ("rel"	"\\dashVdash"	#X27DB)
    ("rel"	"\\multimapinv"	#X27DC)
    ("rel"	"\\vlongdash"	#X27DD)
    ("rel"	"\\longdashv"	#X27DE)
    ("rel"	"\\cirbot"	#X27DF)
    ("bin"	"\\lozengeminus"	#X27E0)
    ("bin"	"\\concavediamond"	#X27E1)
    ("bin"	"\\concavediamondtickleft"	#X27E2)
    ("bin"	"\\concavediamondtickright "	#X27E3)
    ("bin"	"\\whitesquaretickleft"	#X27E4)
    ("bin"	"\\whitesquaretickright"	#X27E5)
    ("open"	"\\lBrack"	#X27E6)
    ("close"	"\\rBrack"	#X27E7)
    ("open"	"\\langle"	#X27E8)
    ("close"	"\\rangle"	#X27E9)
    ("open"	"\\lAngle"	#X27EA)
    ("close"	"\\rAngle"	#X27EB)
    ("open"	"\\Lbrbrak"	#X27EC)
    ("close"	"\\Rbrbrak"	#X27ED)
    ("rel"	"\\UUparrow"	#X27F0)
    ("rel"	"\\DDownarrow"	#X27F1)
    ("rel"	"\\acwgapcirclearrow"	#X27F2)
    ("rel"	"\\cwgapcirclearrow"	#X27F3)
    ("rel"	"\\rightarrowonoplus"	#X27F4)
    ("rel"	"\\longleftarrow"	#X27F5)
    ("rel"	"\\longrightarrow"	#X27F6)
    ("rel"	"\\longleftrightarrow"	#X27F7)
    ("rel"	"\\Longleftarrow"	#X27F8)
    ("rel"	"\\Longrightarrow"	#X27F9)
    ("rel"	"\\Longleftrightarrow"	#X27FA)
    ("rel"	"\\longmapsfrom"	#X27FB)
    ("rel"	"\\longmapsto"	#X27FC)
    ("rel"	"\\Longmapsfrom"	#X27FD)
    ("rel"	"\\Longmapsto"	#X27FE)
    ("rel"	"\\longrightsquigarrow"	#X27FF)
    ("rel"	"\\nvtwoheadrightarrow"	#X2900)
    ("rel"	"\\nVtwoheadrightarrow"	#X2901)
    ("rel"	"\\nvLeftarrow"	#X2902)
    ("rel"	"\\nvRightarrow"	#X2903)
    ("rel"	"\\nvLeftrightarrow"	#X2904)
    ("rel"	"\\twoheadmapsto"	#X2905)
    ("rel"	"\\Mapsfrom"	#X2906)
    ("rel"	"\\Mapsto"	#X2907)
    ("rel"	"\\downarrowbarred"	#X2908)
    ("rel"	"\\uparrowbarred"	#X2909)
    ("rel"	"\\Uuparrow"	#X290A)
    ("rel"	"\\Ddownarrow"	#X290B)
    ("rel"	"\\leftbkarrow"	#X290C)
    ("rel"	"\\rightbkarrow"	#X290D)
    ("rel"	"\\leftdbkarrow"	#X290E)
    ("rel"	"\\dbkarow"	#X290F)
    ("rel"	"\\drbkarow"	#X2910)
    ("rel"	"\\rightdotarrow"	#X2911)
    ("rel"	"\\baruparrow"	#X2912)
    ("rel"	"\\downarrowbar"	#X2913)
    ("rel"	"\\nvrightarrowtail"	#X2914)
    ("rel"	"\\nVrightarrowtail"	#X2915)
    ("rel"	"\\twoheadrightarrowtail"	#X2916)
    ("rel"	"\\nvtwoheadrightarrowtail "	#X2917)
    ("rel"	"\\nVtwoheadrightarrowtail "	#X2918)
    ("rel"	"\\lefttail"	#X2919)
    ("rel"	"\\righttail"	#X291A)
    ("rel"	"\\leftdbltail"	#X291B)
    ("rel"	"\\rightdbltail"	#X291C)
    ("rel"	"\\diamondleftarrow"	#X291D)
    ("rel"	"\\rightarrowdiamond"	#X291E)
    ("rel"	"\\diamondleftarrowbar"	#X291F)
    ("rel"	"\\barrightarrowdiamond"	#X2920)
    ("rel"	"\\nwsearrow"	#X2921)
    ("rel"	"\\neswarrow"	#X2922)
    ("rel"	"\\hknwarrow"	#X2923)
    ("rel"	"\\hknearrow"	#X2924)
    ("rel"	"\\hksearow"	#X2925)
    ("rel"	"\\hkswarow"	#X2926)
    ("rel"	"\\tona"	#X2927)
    ("rel"	"\\toea"	#X2928)
    ("rel"	"\\tosa"	#X2929)
    ("rel"	"\\towa"	#X292A)
    ("ord"	"\\rdiagovfdiag"	#X292B)
    ("ord"	"\\fdiagovrdiag"	#X292C)
    ("ord"	"\\seovnearrow"	#X292D)
    ("ord"	"\\neovsearrow"	#X292E)
    ("ord"	"\\fdiagovnearrow"	#X292F)
    ("ord"	"\\rdiagovsearrow"	#X2930)
    ("ord"	"\\neovnwarrow"	#X2931)
    ("ord"	"\\nwovnearrow"	#X2932)
    ("rel"	"\\rightcurvedarrow"	#X2933)
    ("ord"	"\\uprightcurvearrow"	#X2934)
    ("ord"	"\\downrightcurvedarrow"	#X2935)
    ("rel"	"\\leftdowncurvedarrow"	#X2936)
    ("rel"	"\\rightdowncurvedarrow"	#X2937)
    ("rel"	"\\cwrightarcarrow"	#X2938)
    ("rel"	"\\acwleftarcarrow"	#X2939)
    ("rel"	"\\acwoverarcarrow"	#X293A)
    ("rel"	"\\acwunderarcarrow"	#X293B)
    ("rel"	"\\curvearrowrightminus"	#X293C)
    ("rel"	"\\curvearrowleftplus"	#X293D)
    ("rel"	"\\cwundercurvearrow"	#X293E)
    ("rel"	"\\ccwundercurvearrow"	#X293F)
    ("rel"	"\\acwcirclearrow"	#X2940)
    ("rel"	"\\cwcirclearrow"	#X2941)
    ("rel"	"\\rightarrowshortleftarrow"	#X2942)
    ("rel"	"\\leftarrowshortrightarrow"	#X2943)
    ("rel"	"\\shortrightarrowleftarrow"	#X2944)
    ("rel"	"\\rightarrowplus"	#X2945)
    ("rel"	"\\leftarrowplus"	#X2946)
    ("rel"	"\\rightarrowx"	#X2947)
    ("rel"	"\\leftrightarrowcircle"	#X2948)
    ("rel"	"\\twoheaduparrowcircle"	#X2949)
    ("rel"	"\\leftrightharpoonupdown"	#X294A)
    ("rel"	"\\leftrightharpoondownup"	#X294B)
    ("rel"	"\\updownharpoonrightleft"	#X294C)
    ("rel"	"\\updownharpoonleftright"	#X294D)
    ("rel"	"\\leftrightharpoonupup"	#X294E)
    ("rel"	"\\updownharpoonrightright "	#X294F)
    ("rel"	"\\leftrightharpoondowndown"	#X2950)
    ("rel"	"\\updownharpoonleftleft"	#X2951)
    ("rel"	"\\barleftharpoonup"	#X2952)
    ("rel"	"\\rightharpoonupbar"	#X2953)
    ("rel"	"\\barupharpoonright"	#X2954)
    ("rel"	"\\downharpoonrightbar"	#X2955)
    ("rel"	"\\barleftharpoondown"	#X2956)
    ("rel"	"\\rightharpoondownbar"	#X2957)
    ("rel"	"\\barupharpoonleft"	#X2958)
    ("rel"	"\\downharpoonleftbar"	#X2959)
    ("rel"	"\\leftharpoonupbar"	#X295A)
    ("rel"	"\\barrightharpoonup"	#X295B)
    ("rel"	"\\upharpoonrightbar"	#X295C)
    ("rel"	"\\bardownharpoonright"	#X295D)
    ("rel"	"\\leftharpoondownbar"	#X295E)
    ("rel"	"\\barrightharpoondown"	#X295F)
    ("rel"	"\\upharpoonleftbar"	#X2960)
    ("rel"	"\\bardownharpoonleft"	#X2961)
    ("rel"	"\\leftharpoonsupdown"	#X2962)
    ("rel"	"\\upharpoonsleftright"	#X2963)
    ("rel"	"\\rightharpoonsupdown"	#X2964)
    ("rel"	"\\downharpoonsleftright"	#X2965)
    ("rel"	"\\leftrightharpoonsup"	#X2966)
    ("rel"	"\\leftrightharpoonsdown"	#X2967)
    ("rel"	"\\rightleftharpoonsup"	#X2968)
    ("rel"	"\\rightleftharpoonsdown"	#X2969)
    ("rel"	"\\leftharpoonupdash"	#X296A)
    ("rel"	"\\dashleftharpoondown"	#X296B)
    ("rel"	"\\rightharpoonupdash"	#X296C)
    ("rel"	"\\dashrightharpoondown"	#X296D)
    ("rel"	"\\updownharpoonsleftright "	#X296E)
    ("rel"	"\\downupharpoonsleftright "	#X296F)
    ("rel"	"\\rightimply"	#X2970)
    ("rel"	"\\equalrightarrow"	#X2971)
    ("rel"	"\\similarrightarrow"	#X2972)
    ("rel"	"\\leftarrowsimilar"	#X2973)
    ("rel"	"\\rightarrowsimilar"	#X2974)
    ("rel"	"\\rightarrowapprox"	#X2975)
    ("rel"	"\\ltlarr"	#X2976)
    ("rel"	"\\leftarrowless"	#X2977)
    ("rel"	"\\gtrarr"	#X2978)
    ("rel"	"\\subrarr"	#X2979)
    ("rel"	"\\leftarrowsubset"	#X297A)
    ("rel"	"\\suplarr"	#X297B)
    ("rel"	"\\leftfishtail"	#X297C)
    ("rel"	"\\rightfishtail"	#X297D)
    ("rel"	"\\upfishtail"	#X297E)
    ("rel"	"\\downfishtail"	#X297F)
    ("fence"	"\\Vvert"	#X2980)
    ("ord"	"\\mdsmblkcircle"	#X2981)
    ("bin"	"\\typecolon"	#X2982)
    ("open"	"\\lBrace"	#X2983)
    ("close"	"\\rBrace"	#X2984)
    ("open"	"\\lParen"	#X2985)
    ("close"	"\\rParen"	#X2986)
    ("open"	"\\llparenthesis"	#X2987)
    ("close"	"\\rrparenthesis"	#X2988)
    ("open"	"\\llangle"	#X2989)
    ("close"	"\\rrangle"	#X298A)
    ("open"	"\\lbrackubar"	#X298B)
    ("close"	"\\rbrackubar"	#X298C)
    ("open"	"\\lbrackultick"	#X298D)
    ("close"	"\\rbracklrtick"	#X298E)
    ("open"	"\\lbracklltick"	#X298F)
    ("close"	"\\rbrackurtick"	#X2990)
    ("open"	"\\langledot"	#X2991)
    ("close"	"\\rangledot"	#X2992)
    ("open"	"\\lparenless"	#X2993)
    ("close"	"\\rparengtr"	#X2994)
    ("open"	"\\Lparengtr"	#X2995)
    ("close"	"\\Rparenless"	#X2996)
    ("open"	"\\lblkbrbrak"	#X2997)
    ("close"	"\\rblkbrbrak"	#X2998)
    ("ord"	"\\fourvdots"	#X2999)
    ("ord"	"\\vzigzag"	#X299A)
    ("ord"	"\\measuredangleleft"	#X299B)
    ("ord"	"\\rightanglesqr"	#X299C)
    ("ord"	"\\rightanglemdot"	#X299D)
    ("ord"	"\\angles"	#X299E)
    ("ord"	"\\angdnr"	#X299F)
    ("ord"	"\\gtlpar"	#X29A0)
    ("ord"	"\\sphericalangleup"	#X29A1)
    ("ord"	"\\turnangle"	#X29A2)
    ("ord"	"\\revangle"	#X29A3)
    ("ord"	"\\angleubar"	#X29A4)
    ("ord"	"\\revangleubar"	#X29A5)
    ("ord"	"\\wideangledown"	#X29A6)
    ("ord"	"\\wideangleup"	#X29A7)
    ("ord"	"\\measanglerutone"	#X29A8)
    ("ord"	"\\measanglelutonw"	#X29A9)
    ("ord"	"\\measanglerdtose"	#X29AA)
    ("ord"	"\\measangleldtosw"	#X29AB)
    ("ord"	"\\measangleurtone"	#X29AC)
    ("ord"	"\\measangleultonw"	#X29AD)
    ("ord"	"\\measangledrtose"	#X29AE)
    ("ord"	"\\measangledltosw"	#X29AF)
    ("ord"	"\\revemptyset"	#X29B0)
    ("ord"	"\\emptysetobar"	#X29B1)
    ("ord"	"\\emptysetocirc"	#X29B2)
    ("ord"	"\\emptysetoarr"	#X29B3)
    ("ord"	"\\emptysetoarrl"	#X29B4)
    ("bin"	"\\circlehbar"	#X29B5)
    ("bin"	"\\circledvert"	#X29B6)
    ("bin"	"\\circledparallel"	#X29B7)
    ("bin"	"\\obslash"	#X29B8)
    ("bin"	"\\operp"	#X29B9)
    ("ord"	"\\obot"	#X29BA)
    ("ord"	"\\olcross"	#X29BB)
    ("ord"	"\\odotslashdot"	#X29BC)
    ("ord"	"\\uparrowoncircle"	#X29BD)
    ("ord"	"\\circledwhitebullet"	#X29BE)
    ("ord"	"\\circledbullet"	#X29BF)
    ("bin"	"\\olessthan"	#X29C0)
    ("bin"	"\\ogreaterthan"	#X29C1)
    ("ord"	"\\cirscir"	#X29C2)
    ("ord"	"\\cirE"	#X29C3)
    ("bin"	"\\boxdiag"	#X29C4)
    ("bin"	"\\boxbslash"	#X29C5)
    ("bin"	"\\boxast"	#X29C6)
    ("bin"	"\\boxcircle"	#X29C7)
    ("bin"	"\\boxbox"	#X29C8)
    ("ord"	"\\boxonbox"	#X29C9)
    ("ord"	"\\triangleodot"	#X29CA)
    ("ord"	"\\triangleubar"	#X29CB)
    ("ord"	"\\triangles"	#X29CC)
    ("bin"	"\\triangleserifs"	#X29CD)
    ("rel"	"\\rtriltri"	#X29CE)
    ("rel"	"\\ltrivb"	#X29CF)
    ("rel"	"\\vbrtri"	#X29D0)
    ("rel"	"\\lfbowtie"	#X29D1)
    ("rel"	"\\rfbowtie"	#X29D2)
    ("rel"	"\\fbowtie"	#X29D3)
    ("rel"	"\\lftimes"	#X29D4)
    ("rel"	"\\rftimes"	#X29D5)
    ("bin"	"\\hourglass"	#X29D6)
    ("bin"	"\\blackhourglass"	#X29D7)
    ("open"	"\\lvzigzag"	#X29D8)
    ("close"	"\\rvzigzag"	#X29D9)
    ("open"	"\\Lvzigzag"	#X29DA)
    ("close"	"\\Rvzigzag"	#X29DB)
    ("ord"	"\\iinfin"	#X29DC)
    ("ord"	"\\tieinfty"	#X29DD)
    ("ord"	"\\nvinfty"	#X29DE)
    ("rel"	"\\dualmap"	#X29DF)
    ("ord"	"\\laplac"	#X29E0)
    ("rel"	"\\lrtriangleeq"	#X29E1)
    ("bin"	"\\shuffle"	#X29E2)
    ("rel"	"\\eparsl"	#X29E3)
    ("rel"	"\\smeparsl"	#X29E4)
    ("rel"	"\\eqvparsl"	#X29E5)
    ("rel"	"\\gleichstark"	#X29E6)
    ("ord"	"\\thermod"	#X29E7)
    ("ord"	"\\downtriangleleftblack"	#X29E8)
    ("ord"	"\\downtrianglerightblack"	#X29E9)
    ("ord"	"\\blackdiamonddownarrow"	#X29EA)
    ("bin"	"\\mdlgblklozenge"	#X29EB)
    ("ord"	"\\circledownarrow"	#X29EC)
    ("ord"	"\\blackcircledownarrow"	#X29ED)
    ("ord"	"\\errbarsquare"	#X29EE)
    ("ord"	"\\errbarblacksquare"	#X29EF)
    ("ord"	"\\errbardiamond"	#X29F0)
    ("ord"	"\\errbarblackdiamond"	#X29F1)
    ("ord"	"\\errbarcircle"	#X29F2)
    ("ord"	"\\errbarblackcircle"	#X29F3)
    ("rel"	"\\ruledelayed"	#X29F4)
    ("bin"	"\\setminus"	#X29F5)
    ("bin"	"\\dsol"	#X29F6)
    ("bin"	"\\rsolbar"	#X29F7)
    ("op"	"\\xsol"	#X29F8)
    ("op"	"\\xbsol"	#X29F9)
    ("bin"	"\\doubleplus"	#X29FA)
    ("bin"	"\\tripleplus"	#X29FB)
    ("open"	"\\lcurvyangle"	#X29FC)
    ("close"	"\\rcurvyangle"	#X29FD)
    ("bin"	"\\tplus"	#X29FE)
    ("bin"	"\\tminus"	#X29FF)
    ("op"	"\\bigodot"	#X2A00)
    ("op"	"\\bigoplus"	#X2A01)
    ("op"	"\\bigotimes"	#X2A02)
    ("op"	"\\bigcupdot"	#X2A03)
    ("op"	"\\biguplus"	#X2A04)
    ("op"	"\\bigsqcap"	#X2A05)
    ("op"	"\\bigsqcup"	#X2A06)
    ("op"	"\\conjquant"	#X2A07)
    ("op"	"\\disjquant"	#X2A08)
    ("op"	"\\bigtimes"	#X2A09)
    ("ord"	"\\modtwosum"	#X2A0A)
    ("op"	"\\sumint"	#X2A0B)
    ("op"	"\\iiiint"	#X2A0C)
    ("op"	"\\intbar"	#X2A0D)
    ("op"	"\\intBar"	#X2A0E)
    ("op"	"\\fint"	#X2A0F)
    ("op"	"\\cirfnint"	#X2A10)
    ("op"	"\\awint"	#X2A11)
    ("op"	"\\rppolint"	#X2A12)
    ("op"	"\\scpolint"	#X2A13)
    ("op"	"\\npolint"	#X2A14)
    ("op"	"\\pointint"	#X2A15)
    ("op"	"\\sqint"	#X2A16)
    ("op"	"\\intlarhk"	#X2A17)
    ("op"	"\\intx"	#X2A18)
    ("op"	"\\intcap"	#X2A19)
    ("op"	"\\intcup"	#X2A1A)
    ("op"	"\\upint"	#X2A1B)
    ("op"	"\\lowint"	#X2A1C)
    ("op"	"\\Join"	#X2A1D)
    ("op"	"\\bigtriangleleft"	#X2A1E)
    ("op"	"\\zcmp"	#X2A1F)
    ("op"	"\\zpipe"	#X2A20)
    ("op"	"\\zproject"	#X2A21)
    ("bin"	"\\ringplus"	#X2A22)
    ("bin"	"\\plushat"	#X2A23)
    ("bin"	"\\simplus"	#X2A24)
    ("bin"	"\\plusdot"	#X2A25)
    ("bin"	"\\plussim"	#X2A26)
    ("bin"	"\\plussubtwo"	#X2A27)
    ("bin"	"\\plustrif"	#X2A28)
    ("bin"	"\\commaminus"	#X2A29)
    ("bin"	"\\minusdot"	#X2A2A)
    ("bin"	"\\minusfdots"	#X2A2B)
    ("bin"	"\\minusrdots"	#X2A2C)
    ("bin"	"\\opluslhrim"	#X2A2D)
    ("bin"	"\\oplusrhrim"	#X2A2E)
    ("bin"	"\\vectimes"	#X2A2F)
    ("bin"	"\\dottimes"	#X2A30)
    ("bin"	"\\timesbar"	#X2A31)
    ("bin"	"\\btimes"	#X2A32)
    ("bin"	"\\smashtimes"	#X2A33)
    ("bin"	"\\otimeslhrim"	#X2A34)
    ("bin"	"\\otimesrhrim"	#X2A35)
    ("bin"	"\\otimeshat"	#X2A36)
    ("bin"	"\\Otimes"	#X2A37)
    ("bin"	"\\odiv"	#X2A38)
    ("bin"	"\\triangleplus"	#X2A39)
    ("bin"	"\\triangleminus"	#X2A3A)
    ("bin"	"\\triangletimes"	#X2A3B)
    ("bin"	"\\intprod"	#X2A3C)
    ("bin"	"\\intprodr"	#X2A3D)
    ("bin"	"\\fcmp"	#X2A3E)
    ("bin"	"\\amalg"	#X2A3F)
    ("bin"	"\\capdot"	#X2A40)
    ("bin"	"\\uminus"	#X2A41)
    ("bin"	"\\barcup"	#X2A42)
    ("bin"	"\\barcap"	#X2A43)
    ("bin"	"\\capwedge"	#X2A44)
    ("bin"	"\\cupvee"	#X2A45)
    ("bin"	"\\cupovercap"	#X2A46)
    ("bin"	"\\capovercup"	#X2A47)
    ("bin"	"\\cupbarcap"	#X2A48)
    ("bin"	"\\capbarcup"	#X2A49)
    ("bin"	"\\twocups"	#X2A4A)
    ("bin"	"\\twocaps"	#X2A4B)
    ("bin"	"\\closedvarcup"	#X2A4C)
    ("bin"	"\\closedvarcap"	#X2A4D)
    ("bin"	"\\Sqcap"	#X2A4E)
    ("bin"	"\\Sqcup"	#X2A4F)
    ("bin"	"\\closedvarcupsmashprod"	#X2A50)
    ("bin"	"\\wedgeodot"	#X2A51)
    ("bin"	"\\veeodot"	#X2A52)
    ("bin"	"\\Wedge"	#X2A53)
    ("bin"	"\\Vee"	#X2A54)
    ("bin"	"\\wedgeonwedge"	#X2A55)
    ("bin"	"\\veeonvee"	#X2A56)
    ("bin"	"\\bigslopedvee"	#X2A57)
    ("bin"	"\\bigslopedwedge"	#X2A58)
    ("rel"	"\\veeonwedge"	#X2A59)
    ("bin"	"\\wedgemidvert"	#X2A5A)
    ("bin"	"\\veemidvert"	#X2A5B)
    ("bin"	"\\midbarwedge"	#X2A5C)
    ("bin"	"\\midbarvee"	#X2A5D)
    ("bin"	"\\doublebarwedge"	#X2A5E)
    ("bin"	"\\wedgebar"	#X2A5F)
    ("bin"	"\\wedgedoublebar"	#X2A60)
    ("bin"	"\\varveebar"	#X2A61)
    ("bin"	"\\doublebarvee"	#X2A62)
    ("bin"	"\\veedoublebar"	#X2A63)
    ("bin"	"\\dsub"	#X2A64)
    ("bin"	"\\rsub"	#X2A65)
    ("rel"	"\\eqdot"	#X2A66)
    ("rel"	"\\dotequiv"	#X2A67)
    ("rel"	"\\equivVert"	#X2A68)
    ("rel"	"\\equivVvert"	#X2A69)
    ("rel"	"\\dotsim"	#X2A6A)
    ("rel"	"\\simrdots"	#X2A6B)
    ("rel"	"\\simminussim"	#X2A6C)
    ("rel"	"\\congdot"	#X2A6D)
    ("rel"	"\\asteq"	#X2A6E)
    ("rel"	"\\hatapprox"	#X2A6F)
    ("rel"	"\\approxeqq"	#X2A70)
    ("bin"	"\\eqqplus"	#X2A71)
    ("bin"	"\\pluseqq"	#X2A72)
    ("rel"	"\\eqqsim"	#X2A73)
    ("rel"	"\\Coloneq"	#X2A74)
    ("rel"	"\\eqeq"	#X2A75)
    ("rel"	"\\eqeqeq"	#X2A76)
    ("rel"	"\\ddotseq"	#X2A77)
    ("rel"	"\\equivDD"	#X2A78)
    ("rel"	"\\ltcir"	#X2A79)
    ("rel"	"\\gtcir"	#X2A7A)
    ("rel"	"\\ltquest"	#X2A7B)
    ("rel"	"\\gtquest"	#X2A7C)
    ("rel"	"\\leqslant"	#X2A7D)
    ("rel"	"\\geqslant"	#X2A7E)
    ("rel"	"\\lesdot"	#X2A7F)
    ("rel"	"\\gesdot"	#X2A80)
    ("rel"	"\\lesdoto"	#X2A81)
    ("rel"	"\\gesdoto"	#X2A82)
    ("rel"	"\\lesdotor"	#X2A83)
    ("rel"	"\\gesdotol"	#X2A84)
    ("rel"	"\\lessapprox"	#X2A85)
    ("rel"	"\\gtrapprox"	#X2A86)
    ("rel"	"\\lneq"	#X2A87)
    ("rel"	"\\gneq"	#X2A88)
    ("rel"	"\\lnapprox"	#X2A89)
    ("rel"	"\\gnapprox"	#X2A8A)
    ("rel"	"\\lesseqqgtr"	#X2A8B)
    ("rel"	"\\gtreqqless"	#X2A8C)
    ("rel"	"\\lsime"	#X2A8D)
    ("rel"	"\\gsime"	#X2A8E)
    ("rel"	"\\lsimg"	#X2A8F)
    ("rel"	"\\gsiml"	#X2A90)
    ("rel"	"\\lgE"	#X2A91)
    ("rel"	"\\glE"	#X2A92)
    ("rel"	"\\lesges"	#X2A93)
    ("rel"	"\\gesles"	#X2A94)
    ("rel"	"\\eqslantless"	#X2A95)
    ("rel"	"\\eqslantgtr"	#X2A96)
    ("rel"	"\\elsdot"	#X2A97)
    ("rel"	"\\egsdot"	#X2A98)
    ("rel"	"\\eqqless"	#X2A99)
    ("rel"	"\\eqqgtr"	#X2A9A)
    ("rel"	"\\eqqslantless"	#X2A9B)
    ("rel"	"\\eqqslantgtr"	#X2A9C)
    ("rel"	"\\simless"	#X2A9D)
    ("rel"	"\\simgtr"	#X2A9E)
    ("rel"	"\\simlE"	#X2A9F)
    ("rel"	"\\simgE"	#X2AA0)
    ("rel"	"\\Lt"	#X2AA1)
    ("rel"	"\\Gt"	#X2AA2)
    ("rel"	"\\partialmeetcontraction"	#X2AA3)
    ("rel"	"\\glj"	#X2AA4)
    ("rel"	"\\gla"	#X2AA5)
    ("rel"	"\\ltcc"	#X2AA6)
    ("rel"	"\\gtcc"	#X2AA7)
    ("rel"	"\\lescc"	#X2AA8)
    ("rel"	"\\gescc"	#X2AA9)
    ("rel"	"\\smt"	#X2AAA)
    ("rel"	"\\lat"	#X2AAB)
    ("rel"	"\\smte"	#X2AAC)
    ("rel"	"\\late"	#X2AAD)
    ("rel"	"\\bumpeqq"	#X2AAE)
    ("rel"	"\\preceq"	#X2AAF)
    ("rel"	"\\succeq"	#X2AB0)
    ("rel"	"\\precneq"	#X2AB1)
    ("rel"	"\\succneq"	#X2AB2)
    ("rel"	"\\preceqq"	#X2AB3)
    ("rel"	"\\succeqq"	#X2AB4)
    ("rel"	"\\precneqq"	#X2AB5)
    ("rel"	"\\succneqq"	#X2AB6)
    ("rel"	"\\precapprox"	#X2AB7)
    ("rel"	"\\succapprox"	#X2AB8)
    ("rel"	"\\precnapprox"	#X2AB9)
    ("rel"	"\\succnapprox"	#X2ABA)
    ("rel"	"\\Prec"	#X2ABB)
    ("rel"	"\\Succ"	#X2ABC)
    ("rel"	"\\subsetdot"	#X2ABD)
    ("rel"	"\\supsetdot"	#X2ABE)
    ("rel"	"\\subsetplus"	#X2ABF)
    ("rel"	"\\supsetplus"	#X2AC0)
    ("rel"	"\\submult"	#X2AC1)
    ("rel"	"\\supmult"	#X2AC2)
    ("rel"	"\\subedot"	#X2AC3)
    ("rel"	"\\supedot"	#X2AC4)
    ("rel"	"\\subseteqq"	#X2AC5)
    ("rel"	"\\supseteqq"	#X2AC6)
    ("rel"	"\\subsim"	#X2AC7)
    ("rel"	"\\supsim"	#X2AC8)
    ("rel"	"\\subsetapprox"	#X2AC9)
    ("rel"	"\\supsetapprox"	#X2ACA)
    ("rel"	"\\subsetneqq"	#X2ACB)
    ("rel"	"\\supsetneqq"	#X2ACC)
    ("rel"	"\\lsqhook"	#X2ACD)
    ("rel"	"\\rsqhook"	#X2ACE)
    ("rel"	"\\csub"	#X2ACF)
    ("rel"	"\\csup"	#X2AD0)
    ("rel"	"\\csube"	#X2AD1)
    ("rel"	"\\csupe"	#X2AD2)
    ("rel"	"\\subsup"	#X2AD3)
    ("rel"	"\\supsub"	#X2AD4)
    ("rel"	"\\subsub"	#X2AD5)
    ("rel"	"\\supsup"	#X2AD6)
    ("rel"	"\\suphsub"	#X2AD7)
    ("rel"	"\\supdsub"	#X2AD8)
    ("rel"	"\\forkv"	#X2AD9)
    ("rel"	"\\topfork"	#X2ADA)
    ("rel"	"\\mlcp"	#X2ADB)
    ("rel"	"\\forks"	#X2ADC)
    ("rel"	"\\forksnot"	#X2ADD)
    ("rel"	"\\shortlefttack"	#X2ADE)
    ("rel"	"\\shortdowntack"	#X2ADF)
    ("rel"	"\\shortuptack"	#X2AE0)
    ("ord"	"\\perps"	#X2AE1)
    ("rel"	"\\vDdash"	#X2AE2)
    ("rel"	"\\dashV"	#X2AE3)
    ("rel"	"\\Dashv"	#X2AE4)
    ("rel"	"\\DashV"	#X2AE5)
    ("rel"	"\\varVdash"	#X2AE6)
    ("rel"	"\\Barv"	#X2AE7)
    ("rel"	"\\vBar"	#X2AE8)
    ("rel"	"\\vBarv"	#X2AE9)
    ("rel"	"\\barV"	#X2AEA)
    ("rel"	"\\Vbar"	#X2AEB)
    ("rel"	"\\Not"	#X2AEC)
    ("rel"	"\\bNot"	#X2AED)
    ("rel"	"\\revnmid"	#X2AEE)
    ("rel"	"\\cirmid"	#X2AEF)
    ("rel"	"\\midcir"	#X2AF0)
    ("ord"	"\\topcir"	#X2AF1)
    ("rel"	"\\nhpar"	#X2AF2)
    ("rel"	"\\parsim"	#X2AF3)
    ("bin"	"\\interleave"	#X2AF4)
    ("bin"	"\\nhVvert"	#X2AF5)
    ("bin"	"\\threedotcolon"	#X2AF6)
    ("rel"	"\\lllnest"	#X2AF7)
    ("rel"	"\\gggnest"	#X2AF8)
    ("rel"	"\\leqqslant"	#X2AF9)
    ("rel"	"\\geqqslant"	#X2AFA)
    ("bin"	"\\trslash"	#X2AFB)
    ("op"	"\\biginterleave"	#X2AFC)
    ("bin"	"\\sslash"	#X2AFD)
    ("bin"	"\\talloblong"	#X2AFE)
    ("op"	"\\bigtalloblong"	#X2AFF)
    ("ord"	"\\squaretopblack"	#X2B12)
    ("ord"	"\\squarebotblack"	#X2B13)
    ("ord"	"\\squareurblack"	#X2B14)
    ("ord"	"\\squarellblack"	#X2B15)
    ("ord"	"\\diamondleftblack"	#X2B16)
    ("ord"	"\\diamondrightblack"	#X2B17)
    ("ord"	"\\diamondtopblack"	#X2B18)
    ("ord"	"\\diamondbotblack"	#X2B19)
    ("ord"	"\\dottedsquare"	#X2B1A)
    ("ord"	"\\lgblksquare"	#X2B1B)
    ("ord"	"\\lgwhtsquare"	#X2B1C)
    ("ord"	"\\vysmblksquare"	#X2B1D)
    ("ord"	"\\vysmwhtsquare"	#X2B1E)
    ("ord"	"\\pentagonblack"	#X2B1F)
    ("ord"	"\\pentagon"	#X2B20)
    ("ord"	"\\varhexagon"	#X2B21)
    ("ord"	"\\varhexagonblack"	#X2B22)
    ("ord"	"\\hexagonblack"	#X2B23)
    ("ord"	"\\lgblkcircle"	#X2B24)
    ("ord"	"\\mdblkdiamond"	#X2B25)
    ("ord"	"\\mdwhtdiamond"	#X2B26)
    ("ord"	"\\mdblklozenge"	#X2B27)
    ("ord"	"\\mdwhtlozenge"	#X2B28)
    ("ord"	"\\smblkdiamond"	#X2B29)
    ("ord"	"\\smblklozenge"	#X2B2A)
    ("ord"	"\\smwhtlozenge"	#X2B2B)
    ("ord"	"\\blkhorzoval"	#X2B2C)
    ("ord"	"\\whthorzoval"	#X2B2D)
    ("ord"	"\\blkvertoval"	#X2B2E)
    ("ord"	"\\whtvertoval"	#X2B2F)
    ("rel"	"\\circleonleftarrow"	#X2B30)
    ("rel"	"\\leftthreearrows"	#X2B31)
    ("rel"	"\\leftarrowonoplus"	#X2B32)
    ("rel"	"\\longleftsquigarrow"	#X2B33)
    ("rel"	"\\nvtwoheadleftarrow"	#X2B34)
    ("rel"	"\\nVtwoheadleftarrow"	#X2B35)
    ("rel"	"\\twoheadmapsfrom"	#X2B36)
    ("rel"	"\\twoheadleftdbkarrow"	#X2B37)
    ("rel"	"\\leftdotarrow"	#X2B38)
    ("rel"	"\\nvleftarrowtail"	#X2B39)
    ("rel"	"\\nVleftarrowtail"	#X2B3A)
    ("rel"	"\\twoheadleftarrowtail"	#X2B3B)
    ("rel"	"\\nvtwoheadleftarrowtail"	#X2B3C)
    ("rel"	"\\nVtwoheadleftarrowtail"	#X2B3D)
    ("rel"	"\\leftarrowx"	#X2B3E)
    ("rel"	"\\leftcurvedarrow"	#X2B3F)
    ("rel"	"\\equalleftarrow"	#X2B40)
    ("rel"	"\\bsimilarleftarrow"	#X2B41)
    ("rel"	"\\leftarrowbackapprox"	#X2B42)
    ("rel"	"\\rightarrowgtr"	#X2B43)
    ("rel"	"\\rightarrowsupset"	#X2B44)
    ("rel"	"\\LLeftarrow"	#X2B45)
    ("rel"	"\\RRightarrow"	#X2B46)
    ("rel"	"\\bsimilarrightarrow"	#X2B47)
    ("rel"	"\\rightarrowbackapprox"	#X2B48)
    ("rel"	"\\similarleftarrow"	#X2B49)
    ("rel"	"\\leftarrowapprox"	#X2B4A)
    ("rel"	"\\leftarrowbsimilar"	#X2B4B)
    ("rel"	"\\rightarrowbsimilar"	#X2B4C)
    ("ord"	"\\medwhitestar"	#X2B50)
    ("ord"	"\\medblackstar"	#X2B51)
    ("ord"	"\\smwhitestar"	#X2B52)
    ("ord"	"\\rightpentagonblack"	#X2B53)
    ("ord"	"\\rightpentagon"	#X2B54)
    ("ord"	"\\postalmark"	#X3012)
    ("open"	"\\lbrbrak"	#X3014)
    ("close"	"\\rbrbrak"	#X3015)
    ("open"	"\\Lbrbrak"	#X3018)
    ("close"	"\\Rbrbrak"	#X3019)
    ("ord"	"\\hzigzag"	#X3030)
    ("alpha"	"\\mbfA"	#X1D400)
    ("alpha"	"\\mbfB"	#X1D401)
    ("alpha"	"\\mbfC"	#X1D402)
    ("alpha"	"\\mbfD"	#X1D403)
    ("alpha"	"\\mbfE"	#X1D404)
    ("alpha"	"\\mbfF"	#X1D405)
    ("alpha"	"\\mbfG"	#X1D406)
    ("alpha"	"\\mbfH"	#X1D407)
    ("alpha"	"\\mbfI"	#X1D408)
    ("alpha"	"\\mbfJ"	#X1D409)
    ("alpha"	"\\mbfK"	#X1D40A)
    ("alpha"	"\\mbfL"	#X1D40B)
    ("alpha"	"\\mbfM"	#X1D40C)
    ("alpha"	"\\mbfN"	#X1D40D)
    ("alpha"	"\\mbfO"	#X1D40E)
    ("alpha"	"\\mbfP"	#X1D40F)
    ("alpha"	"\\mbfQ"	#X1D410)
    ("alpha"	"\\mbfR"	#X1D411)
    ("alpha"	"\\mbfS"	#X1D412)
    ("alpha"	"\\mbfT"	#X1D413)
    ("alpha"	"\\mbfU"	#X1D414)
    ("alpha"	"\\mbfV"	#X1D415)
    ("alpha"	"\\mbfW"	#X1D416)
    ("alpha"	"\\mbfX"	#X1D417)
    ("alpha"	"\\mbfY"	#X1D418)
    ("alpha"	"\\mbfZ"	#X1D419)
    ("alpha"	"\\mbfa"	#X1D41A)
    ("alpha"	"\\mbfb"	#X1D41B)
    ("alpha"	"\\mbfc"	#X1D41C)
    ("alpha"	"\\mbfd"	#X1D41D)
    ("alpha"	"\\mbfe"	#X1D41E)
    ("alpha"	"\\mbff"	#X1D41F)
    ("alpha"	"\\mbfg"	#X1D420)
    ("alpha"	"\\mbfh"	#X1D421)
    ("alpha"	"\\mbfi"	#X1D422)
    ("alpha"	"\\mbfj"	#X1D423)
    ("alpha"	"\\mbfk"	#X1D424)
    ("alpha"	"\\mbfl"	#X1D425)
    ("alpha"	"\\mbfm"	#X1D426)
    ("alpha"	"\\mbfn"	#X1D427)
    ("alpha"	"\\mbfo"	#X1D428)
    ("alpha"	"\\mbfp"	#X1D429)
    ("alpha"	"\\mbfq"	#X1D42A)
    ("alpha"	"\\mbfr"	#X1D42B)
    ("alpha"	"\\mbfs"	#X1D42C)
    ("alpha"	"\\mbft"	#X1D42D)
    ("alpha"	"\\mbfu"	#X1D42E)
    ("alpha"	"\\mbfv"	#X1D42F)
    ("alpha"	"\\mbfw"	#X1D430)
    ("alpha"	"\\mbfx"	#X1D431)
    ("alpha"	"\\mbfy"	#X1D432)
    ("alpha"	"\\mbfz"	#X1D433)
    ("alpha"	"\\mitA"	#X1D434)
    ("alpha"	"\\mitB"	#X1D435)
    ("alpha"	"\\mitC"	#X1D436)
    ("alpha"	"\\mitD"	#X1D437)
    ("alpha"	"\\mitE"	#X1D438)
    ("alpha"	"\\mitF"	#X1D439)
    ("alpha"	"\\mitG"	#X1D43A)
    ("alpha"	"\\mitH"	#X1D43B)
    ("alpha"	"\\mitI"	#X1D43C)
    ("alpha"	"\\mitJ"	#X1D43D)
    ("alpha"	"\\mitK"	#X1D43E)
    ("alpha"	"\\mitL"	#X1D43F)
    ("alpha"	"\\mitM"	#X1D440)
    ("alpha"	"\\mitN"	#X1D441)
    ("alpha"	"\\mitO"	#X1D442)
    ("alpha"	"\\mitP"	#X1D443)
    ("alpha"	"\\mitQ"	#X1D444)
    ("alpha"	"\\mitR"	#X1D445)
    ("alpha"	"\\mitS"	#X1D446)
    ("alpha"	"\\mitT"	#X1D447)
    ("alpha"	"\\mitU"	#X1D448)
    ("alpha"	"\\mitV"	#X1D449)
    ("alpha"	"\\mitW"	#X1D44A)
    ("alpha"	"\\mitX"	#X1D44B)
    ("alpha"	"\\mitY"	#X1D44C)
    ("alpha"	"\\mitZ"	#X1D44D)
    ("alpha"	"\\mita"	#X1D44E)
    ("alpha"	"\\mitb"	#X1D44F)
    ("alpha"	"\\mitc"	#X1D450)
    ("alpha"	"\\mitd"	#X1D451)
    ("alpha"	"\\mite"	#X1D452)
    ("alpha"	"\\mitf"	#X1D453)
    ("alpha"	"\\mitg"	#X1D454)
    ("alpha"	"\\miti"	#X1D456)
    ("alpha"	"\\mitj"	#X1D457)
    ("alpha"	"\\mitk"	#X1D458)
    ("alpha"	"\\mitl"	#X1D459)
    ("alpha"	"\\mitm"	#X1D45A)
    ("alpha"	"\\mitn"	#X1D45B)
    ("alpha"	"\\mito"	#X1D45C)
    ("alpha"	"\\mitp"	#X1D45D)
    ("alpha"	"\\mitq"	#X1D45E)
    ("alpha"	"\\mitr"	#X1D45F)
    ("alpha"	"\\mits"	#X1D460)
    ("alpha"	"\\mitt"	#X1D461)
    ("alpha"	"\\mitu"	#X1D462)
    ("alpha"	"\\mitv"	#X1D463)
    ("alpha"	"\\mitw"	#X1D464)
    ("alpha"	"\\mitx"	#X1D465)
    ("alpha"	"\\mity"	#X1D466)
    ("alpha"	"\\mitz"	#X1D467)
    ("alpha"	"\\mbfitA"	#X1D468)
    ("alpha"	"\\mbfitB"	#X1D469)
    ("alpha"	"\\mbfitC"	#X1D46A)
    ("alpha"	"\\mbfitD"	#X1D46B)
    ("alpha"	"\\mbfitE"	#X1D46C)
    ("alpha"	"\\mbfitF"	#X1D46D)
    ("alpha"	"\\mbfitG"	#X1D46E)
    ("alpha"	"\\mbfitH"	#X1D46F)
    ("alpha"	"\\mbfitI"	#X1D470)
    ("alpha"	"\\mbfitJ"	#X1D471)
    ("alpha"	"\\mbfitK"	#X1D472)
    ("alpha"	"\\mbfitL"	#X1D473)
    ("alpha"	"\\mbfitM"	#X1D474)
    ("alpha"	"\\mbfitN"	#X1D475)
    ("alpha"	"\\mbfitO"	#X1D476)
    ("alpha"	"\\mbfitP"	#X1D477)
    ("alpha"	"\\mbfitQ"	#X1D478)
    ("alpha"	"\\mbfitR"	#X1D479)
    ("alpha"	"\\mbfitS"	#X1D47A)
    ("alpha"	"\\mbfitT"	#X1D47B)
    ("alpha"	"\\mbfitU"	#X1D47C)
    ("alpha"	"\\mbfitV"	#X1D47D)
    ("alpha"	"\\mbfitW"	#X1D47E)
    ("alpha"	"\\mbfitX"	#X1D47F)
    ("alpha"	"\\mbfitY"	#X1D480)
    ("alpha"	"\\mbfitZ"	#X1D481)
    ("alpha"	"\\mbfita"	#X1D482)
    ("alpha"	"\\mbfitb"	#X1D483)
    ("alpha"	"\\mbfitc"	#X1D484)
    ("alpha"	"\\mbfitd"	#X1D485)
    ("alpha"	"\\mbfite"	#X1D486)
    ("alpha"	"\\mbfitf"	#X1D487)
    ("alpha"	"\\mbfitg"	#X1D488)
    ("alpha"	"\\mbfith"	#X1D489)
    ("alpha"	"\\mbfiti"	#X1D48A)
    ("alpha"	"\\mbfitj"	#X1D48B)
    ("alpha"	"\\mbfitk"	#X1D48C)
    ("alpha"	"\\mbfitl"	#X1D48D)
    ("alpha"	"\\mbfitm"	#X1D48E)
    ("alpha"	"\\mbfitn"	#X1D48F)
    ("alpha"	"\\mbfito"	#X1D490)
    ("alpha"	"\\mbfitp"	#X1D491)
    ("alpha"	"\\mbfitq"	#X1D492)
    ("alpha"	"\\mbfitr"	#X1D493)
    ("alpha"	"\\mbfits"	#X1D494)
    ("alpha"	"\\mbfitt"	#X1D495)
    ("alpha"	"\\mbfitu"	#X1D496)
    ("alpha"	"\\mbfitv"	#X1D497)
    ("alpha"	"\\mbfitw"	#X1D498)
    ("alpha"	"\\mbfitx"	#X1D499)
    ("alpha"	"\\mbfity"	#X1D49A)
    ("alpha"	"\\mbfitz"	#X1D49B)
    ("alpha"	"\\mscrA"	#X1D49C)
    ("alpha"	"\\mscrC"	#X1D49E)
    ("alpha"	"\\mscrD"	#X1D49F)
    ("alpha"	"\\mscrG"	#X1D4A2)
    ("alpha"	"\\mscrJ"	#X1D4A5)
    ("alpha"	"\\mscrK"	#X1D4A6)
    ("alpha"	"\\mscrN"	#X1D4A9)
    ("alpha"	"\\mscrO"	#X1D4AA)
    ("alpha"	"\\mscrP"	#X1D4AB)
    ("alpha"	"\\mscrQ"	#X1D4AC)
    ("alpha"	"\\mscrS"	#X1D4AE)
    ("alpha"	"\\mscrT"	#X1D4AF)
    ("alpha"	"\\mscrU"	#X1D4B0)
    ("alpha"	"\\mscrV"	#X1D4B1)
    ("alpha"	"\\mscrW"	#X1D4B2)
    ("alpha"	"\\mscrX"	#X1D4B3)
    ("alpha"	"\\mscrY"	#X1D4B4)
    ("alpha"	"\\mscrZ"	#X1D4B5)
    ("alpha"	"\\mscra"	#X1D4B6)
    ("alpha"	"\\mscrb"	#X1D4B7)
    ("alpha"	"\\mscrc"	#X1D4B8)
    ("alpha"	"\\mscrd"	#X1D4B9)
    ("alpha"	"\\mscrf"	#X1D4BB)
    ("alpha"	"\\mscrh"	#X1D4BD)
    ("alpha"	"\\mscri"	#X1D4BE)
    ("alpha"	"\\mscrj"	#X1D4BF)
    ("alpha"	"\\mscrk"	#X1D4C0)
    ("alpha"	"\\mscrl"	#X1D4C1)
    ("alpha"	"\\mscrm"	#X1D4C2)
    ("alpha"	"\\mscrn"	#X1D4C3)
    ("alpha"	"\\mscrp"	#X1D4C5)
    ("alpha"	"\\mscrq"	#X1D4C6)
    ("alpha"	"\\mscrr"	#X1D4C7)
    ("alpha"	"\\mscrs"	#X1D4C8)
    ("alpha"	"\\mscrt"	#X1D4C9)
    ("alpha"	"\\mscru"	#X1D4CA)
    ("alpha"	"\\mscrv"	#X1D4CB)
    ("alpha"	"\\mscrw"	#X1D4CC)
    ("alpha"	"\\mscrx"	#X1D4CD)
    ("alpha"	"\\mscry"	#X1D4CE)
    ("alpha"	"\\mscrz"	#X1D4CF)
    ("alpha"	"\\mbfscrA"	#X1D4D0)
    ("alpha"	"\\mbfscrB"	#X1D4D1)
    ("alpha"	"\\mbfscrC"	#X1D4D2)
    ("alpha"	"\\mbfscrD"	#X1D4D3)
    ("alpha"	"\\mbfscrE"	#X1D4D4)
    ("alpha"	"\\mbfscrF"	#X1D4D5)
    ("alpha"	"\\mbfscrG"	#X1D4D6)
    ("alpha"	"\\mbfscrH"	#X1D4D7)
    ("alpha"	"\\mbfscrI"	#X1D4D8)
    ("alpha"	"\\mbfscrJ"	#X1D4D9)
    ("alpha"	"\\mbfscrK"	#X1D4DA)
    ("alpha"	"\\mbfscrL"	#X1D4DB)
    ("alpha"	"\\mbfscrM"	#X1D4DC)
    ("alpha"	"\\mbfscrN"	#X1D4DD)
    ("alpha"	"\\mbfscrO"	#X1D4DE)
    ("alpha"	"\\mbfscrP"	#X1D4DF)
    ("alpha"	"\\mbfscrQ"	#X1D4E0)
    ("alpha"	"\\mbfscrR"	#X1D4E1)
    ("alpha"	"\\mbfscrS"	#X1D4E2)
    ("alpha"	"\\mbfscrT"	#X1D4E3)
    ("alpha"	"\\mbfscrU"	#X1D4E4)
    ("alpha"	"\\mbfscrV"	#X1D4E5)
    ("alpha"	"\\mbfscrW"	#X1D4E6)
    ("alpha"	"\\mbfscrX"	#X1D4E7)
    ("alpha"	"\\mbfscrY"	#X1D4E8)
    ("alpha"	"\\mbfscrZ"	#X1D4E9)
    ("alpha"	"\\mbfscra"	#X1D4EA)
    ("alpha"	"\\mbfscrb"	#X1D4EB)
    ("alpha"	"\\mbfscrc"	#X1D4EC)
    ("alpha"	"\\mbfscrd"	#X1D4ED)
    ("alpha"	"\\mbfscre"	#X1D4EE)
    ("alpha"	"\\mbfscrf"	#X1D4EF)
    ("alpha"	"\\mbfscrg"	#X1D4F0)
    ("alpha"	"\\mbfscrh"	#X1D4F1)
    ("alpha"	"\\mbfscri"	#X1D4F2)
    ("alpha"	"\\mbfscrj"	#X1D4F3)
    ("alpha"	"\\mbfscrk"	#X1D4F4)
    ("alpha"	"\\mbfscrl"	#X1D4F5)
    ("alpha"	"\\mbfscrm"	#X1D4F6)
    ("alpha"	"\\mbfscrn"	#X1D4F7)
    ("alpha"	"\\mbfscro"	#X1D4F8)
    ("alpha"	"\\mbfscrp"	#X1D4F9)
    ("alpha"	"\\mbfscrq"	#X1D4FA)
    ("alpha"	"\\mbfscrr"	#X1D4FB)
    ("alpha"	"\\mbfscrs"	#X1D4FC)
    ("alpha"	"\\mbfscrt"	#X1D4FD)
    ("alpha"	"\\mbfscru"	#X1D4FE)
    ("alpha"	"\\mbfscrv"	#X1D4FF)
    ("alpha"	"\\mbfscrw"	#X1D500)
    ("alpha"	"\\mbfscrx"	#X1D501)
    ("alpha"	"\\mbfscry"	#X1D502)
    ("alpha"	"\\mbfscrz"	#X1D503)
    ("alpha"	"\\mfrakA"	#X1D504)
    ("alpha"	"\\mfrakB"	#X1D505)
    ("alpha"	"\\mfrakD"	#X1D507)
    ("alpha"	"\\mfrakE"	#X1D508)
    ("alpha"	"\\mfrakF"	#X1D509)
    ("alpha"	"\\mfrakG"	#X1D50A)
    ("alpha"	"\\mfrakJ"	#X1D50D)
    ("alpha"	"\\mfrakK"	#X1D50E)
    ("alpha"	"\\mfrakL"	#X1D50F)
    ("alpha"	"\\mfrakM"	#X1D510)
    ("alpha"	"\\mfrakN"	#X1D511)
    ("alpha"	"\\mfrakO"	#X1D512)
    ("alpha"	"\\mfrakP"	#X1D513)
    ("alpha"	"\\mfrakQ"	#X1D514)
    ("alpha"	"\\mfrakS"	#X1D516)
    ("alpha"	"\\mfrakT"	#X1D517)
    ("alpha"	"\\mfrakU"	#X1D518)
    ("alpha"	"\\mfrakV"	#X1D519)
    ("alpha"	"\\mfrakW"	#X1D51A)
    ("alpha"	"\\mfrakX"	#X1D51B)
    ("alpha"	"\\mfrakY"	#X1D51C)
    ("alpha"	"\\mfraka"	#X1D51E)
    ("alpha"	"\\mfrakb"	#X1D51F)
    ("alpha"	"\\mfrakc"	#X1D520)
    ("alpha"	"\\mfrakd"	#X1D521)
    ("alpha"	"\\mfrake"	#X1D522)
    ("alpha"	"\\mfrakf"	#X1D523)
    ("alpha"	"\\mfrakg"	#X1D524)
    ("alpha"	"\\mfrakh"	#X1D525)
    ("alpha"	"\\mfraki"	#X1D526)
    ("alpha"	"\\mfrakj"	#X1D527)
    ("alpha"	"\\mfrakk"	#X1D528)
    ("alpha"	"\\mfrakl"	#X1D529)
    ("alpha"	"\\mfrakm"	#X1D52A)
    ("alpha"	"\\mfrakn"	#X1D52B)
    ("alpha"	"\\mfrako"	#X1D52C)
    ("alpha"	"\\mfrakp"	#X1D52D)
    ("alpha"	"\\mfrakq"	#X1D52E)
    ("alpha"	"\\mfrakr"	#X1D52F)
    ("alpha"	"\\mfraks"	#X1D530)
    ("alpha"	"\\mfrakt"	#X1D531)
    ("alpha"	"\\mfraku"	#X1D532)
    ("alpha"	"\\mfrakv"	#X1D533)
    ("alpha"	"\\mfrakw"	#X1D534)
    ("alpha"	"\\mfrakx"	#X1D535)
    ("alpha"	"\\mfraky"	#X1D536)
    ("alpha"	"\\mfrakz"	#X1D537)
    ("alpha"	"\\BbbA"	#X1D538)
    ("alpha"	"\\BbbB"	#X1D539)
    ("alpha"	"\\BbbD"	#X1D53B)
    ("alpha"	"\\BbbE"	#X1D53C)
    ("alpha"	"\\BbbF"	#X1D53D)
    ("alpha"	"\\BbbG"	#X1D53E)
    ("alpha"	"\\BbbI"	#X1D540)
    ("alpha"	"\\BbbJ"	#X1D541)
    ("alpha"	"\\BbbK"	#X1D542)
    ("alpha"	"\\BbbL"	#X1D543)
    ("alpha"	"\\BbbM"	#X1D544)
    ("alpha"	"\\BbbO"	#X1D546)
    ("alpha"	"\\BbbS"	#X1D54A)
    ("alpha"	"\\BbbT"	#X1D54B)
    ("alpha"	"\\BbbU"	#X1D54C)
    ("alpha"	"\\BbbV"	#X1D54D)
    ("alpha"	"\\BbbW"	#X1D54E)
    ("alpha"	"\\BbbX"	#X1D54F)
    ("alpha"	"\\BbbY"	#X1D550)
    ("alpha"	"\\Bbba"	#X1D552)
    ("alpha"	"\\Bbbb"	#X1D553)
    ("alpha"	"\\Bbbc"	#X1D554)
    ("alpha"	"\\Bbbd"	#X1D555)
    ("alpha"	"\\Bbbe"	#X1D556)
    ("alpha"	"\\Bbbf"	#X1D557)
    ("alpha"	"\\Bbbg"	#X1D558)
    ("alpha"	"\\Bbbh"	#X1D559)
    ("alpha"	"\\Bbbi"	#X1D55A)
    ("alpha"	"\\Bbbj"	#X1D55B)
    ("alpha"	"\\Bbbk"	#X1D55C)
    ("alpha"	"\\Bbbl"	#X1D55D)
    ("alpha"	"\\Bbbm"	#X1D55E)
    ("alpha"	"\\Bbbn"	#X1D55F)
    ("alpha"	"\\Bbbo"	#X1D560)
    ("alpha"	"\\Bbbp"	#X1D561)
    ("alpha"	"\\Bbbq"	#X1D562)
    ("alpha"	"\\Bbbr"	#X1D563)
    ("alpha"	"\\Bbbs"	#X1D564)
    ("alpha"	"\\Bbbt"	#X1D565)
    ("alpha"	"\\Bbbu"	#X1D566)
    ("alpha"	"\\Bbbv"	#X1D567)
    ("alpha"	"\\Bbbw"	#X1D568)
    ("alpha"	"\\Bbbx"	#X1D569)
    ("alpha"	"\\Bbby"	#X1D56A)
    ("alpha"	"\\Bbbz"	#X1D56B)
    ("alpha"	"\\mbffrakA"	#X1D56C)
    ("alpha"	"\\mbffrakB"	#X1D56D)
    ("alpha"	"\\mbffrakC"	#X1D56E)
    ("alpha"	"\\mbffrakD"	#X1D56F)
    ("alpha"	"\\mbffrakE"	#X1D570)
    ("alpha"	"\\mbffrakF"	#X1D571)
    ("alpha"	"\\mbffrakG"	#X1D572)
    ("alpha"	"\\mbffrakH"	#X1D573)
    ("alpha"	"\\mbffrakI"	#X1D574)
    ("alpha"	"\\mbffrakJ"	#X1D575)
    ("alpha"	"\\mbffrakK"	#X1D576)
    ("alpha"	"\\mbffrakL"	#X1D577)
    ("alpha"	"\\mbffrakM"	#X1D578)
    ("alpha"	"\\mbffrakN"	#X1D579)
    ("alpha"	"\\mbffrakO"	#X1D57A)
    ("alpha"	"\\mbffrakP"	#X1D57B)
    ("alpha"	"\\mbffrakQ"	#X1D57C)
    ("alpha"	"\\mbffrakR"	#X1D57D)
    ("alpha"	"\\mbffrakS"	#X1D57E)
    ("alpha"	"\\mbffrakT"	#X1D57F)
    ("alpha"	"\\mbffrakU"	#X1D580)
    ("alpha"	"\\mbffrakV"	#X1D581)
    ("alpha"	"\\mbffrakW"	#X1D582)
    ("alpha"	"\\mbffrakX"	#X1D583)
    ("alpha"	"\\mbffrakY"	#X1D584)
    ("alpha"	"\\mbffrakZ"	#X1D585)
    ("alpha"	"\\mbffraka"	#X1D586)
    ("alpha"	"\\mbffrakb"	#X1D587)
    ("alpha"	"\\mbffrakc"	#X1D588)
    ("alpha"	"\\mbffrakd"	#X1D589)
    ("alpha"	"\\mbffrake"	#X1D58A)
    ("alpha"	"\\mbffrakf"	#X1D58B)
    ("alpha"	"\\mbffrakg"	#X1D58C)
    ("alpha"	"\\mbffrakh"	#X1D58D)
    ("alpha"	"\\mbffraki"	#X1D58E)
    ("alpha"	"\\mbffrakj"	#X1D58F)
    ("alpha"	"\\mbffrakk"	#X1D590)
    ("alpha"	"\\mbffrakl"	#X1D591)
    ("alpha"	"\\mbffrakm"	#X1D592)
    ("alpha"	"\\mbffrakn"	#X1D593)
    ("alpha"	"\\mbffrako"	#X1D594)
    ("alpha"	"\\mbffrakp"	#X1D595)
    ("alpha"	"\\mbffrakq"	#X1D596)
    ("alpha"	"\\mbffrakr"	#X1D597)
    ("alpha"	"\\mbffraks"	#X1D598)
    ("alpha"	"\\mbffrakt"	#X1D599)
    ("alpha"	"\\mbffraku"	#X1D59A)
    ("alpha"	"\\mbffrakv"	#X1D59B)
    ("alpha"	"\\mbffrakw"	#X1D59C)
    ("alpha"	"\\mbffrakx"	#X1D59D)
    ("alpha"	"\\mbffraky"	#X1D59E)
    ("alpha"	"\\mbffrakz"	#X1D59F)
    ("alpha"	"\\msansA"	#X1D5A0)
    ("alpha"	"\\msansB"	#X1D5A1)
    ("alpha"	"\\msansC"	#X1D5A2)
    ("alpha"	"\\msansD"	#X1D5A3)
    ("alpha"	"\\msansE"	#X1D5A4)
    ("alpha"	"\\msansF"	#X1D5A5)
    ("alpha"	"\\msansG"	#X1D5A6)
    ("alpha"	"\\msansH"	#X1D5A7)
    ("alpha"	"\\msansI"	#X1D5A8)
    ("alpha"	"\\msansJ"	#X1D5A9)
    ("alpha"	"\\msansK"	#X1D5AA)
    ("alpha"	"\\msansL"	#X1D5AB)
    ("alpha"	"\\msansM"	#X1D5AC)
    ("alpha"	"\\msansN"	#X1D5AD)
    ("alpha"	"\\msansO"	#X1D5AE)
    ("alpha"	"\\msansP"	#X1D5AF)
    ("alpha"	"\\msansQ"	#X1D5B0)
    ("alpha"	"\\msansR"	#X1D5B1)
    ("alpha"	"\\msansS"	#X1D5B2)
    ("alpha"	"\\msansT"	#X1D5B3)
    ("alpha"	"\\msansU"	#X1D5B4)
    ("alpha"	"\\msansV"	#X1D5B5)
    ("alpha"	"\\msansW"	#X1D5B6)
    ("alpha"	"\\msansX"	#X1D5B7)
    ("alpha"	"\\msansY"	#X1D5B8)
    ("alpha"	"\\msansZ"	#X1D5B9)
    ("alpha"	"\\msansa"	#X1D5BA)
    ("alpha"	"\\msansb"	#X1D5BB)
    ("alpha"	"\\msansc"	#X1D5BC)
    ("alpha"	"\\msansd"	#X1D5BD)
    ("alpha"	"\\msanse"	#X1D5BE)
    ("alpha"	"\\msansf"	#X1D5BF)
    ("alpha"	"\\msansg"	#X1D5C0)
    ("alpha"	"\\msansh"	#X1D5C1)
    ("alpha"	"\\msansi"	#X1D5C2)
    ("alpha"	"\\msansj"	#X1D5C3)
    ("alpha"	"\\msansk"	#X1D5C4)
    ("alpha"	"\\msansl"	#X1D5C5)
    ("alpha"	"\\msansm"	#X1D5C6)
    ("alpha"	"\\msansn"	#X1D5C7)
    ("alpha"	"\\msanso"	#X1D5C8)
    ("alpha"	"\\msansp"	#X1D5C9)
    ("alpha"	"\\msansq"	#X1D5CA)
    ("alpha"	"\\msansr"	#X1D5CB)
    ("alpha"	"\\msanss"	#X1D5CC)
    ("alpha"	"\\msanst"	#X1D5CD)
    ("alpha"	"\\msansu"	#X1D5CE)
    ("alpha"	"\\msansv"	#X1D5CF)
    ("alpha"	"\\msansw"	#X1D5D0)
    ("alpha"	"\\msansx"	#X1D5D1)
    ("alpha"	"\\msansy"	#X1D5D2)
    ("alpha"	"\\msansz"	#X1D5D3)
    ("alpha"	"\\mbfsansA"	#X1D5D4)
    ("alpha"	"\\mbfsansB"	#X1D5D5)
    ("alpha"	"\\mbfsansC"	#X1D5D6)
    ("alpha"	"\\mbfsansD"	#X1D5D7)
    ("alpha"	"\\mbfsansE"	#X1D5D8)
    ("alpha"	"\\mbfsansF"	#X1D5D9)
    ("alpha"	"\\mbfsansG"	#X1D5DA)
    ("alpha"	"\\mbfsansH"	#X1D5DB)
    ("alpha"	"\\mbfsansI"	#X1D5DC)
    ("alpha"	"\\mbfsansJ"	#X1D5DD)
    ("alpha"	"\\mbfsansK"	#X1D5DE)
    ("alpha"	"\\mbfsansL"	#X1D5DF)
    ("alpha"	"\\mbfsansM"	#X1D5E0)
    ("alpha"	"\\mbfsansN"	#X1D5E1)
    ("alpha"	"\\mbfsansO"	#X1D5E2)
    ("alpha"	"\\mbfsansP"	#X1D5E3)
    ("alpha"	"\\mbfsansQ"	#X1D5E4)
    ("alpha"	"\\mbfsansR"	#X1D5E5)
    ("alpha"	"\\mbfsansS"	#X1D5E6)
    ("alpha"	"\\mbfsansT"	#X1D5E7)
    ("alpha"	"\\mbfsansU"	#X1D5E8)
    ("alpha"	"\\mbfsansV"	#X1D5E9)
    ("alpha"	"\\mbfsansW"	#X1D5EA)
    ("alpha"	"\\mbfsansX"	#X1D5EB)
    ("alpha"	"\\mbfsansY"	#X1D5EC)
    ("alpha"	"\\mbfsansZ"	#X1D5ED)
    ("alpha"	"\\mbfsansa"	#X1D5EE)
    ("alpha"	"\\mbfsansb"	#X1D5EF)
    ("alpha"	"\\mbfsansc"	#X1D5F0)
    ("alpha"	"\\mbfsansd"	#X1D5F1)
    ("alpha"	"\\mbfsanse"	#X1D5F2)
    ("alpha"	"\\mbfsansf"	#X1D5F3)
    ("alpha"	"\\mbfsansg"	#X1D5F4)
    ("alpha"	"\\mbfsansh"	#X1D5F5)
    ("alpha"	"\\mbfsansi"	#X1D5F6)
    ("alpha"	"\\mbfsansj"	#X1D5F7)
    ("alpha"	"\\mbfsansk"	#X1D5F8)
    ("alpha"	"\\mbfsansl"	#X1D5F9)
    ("alpha"	"\\mbfsansm"	#X1D5FA)
    ("alpha"	"\\mbfsansn"	#X1D5FB)
    ("alpha"	"\\mbfsanso"	#X1D5FC)
    ("alpha"	"\\mbfsansp"	#X1D5FD)
    ("alpha"	"\\mbfsansq"	#X1D5FE)
    ("alpha"	"\\mbfsansr"	#X1D5FF)
    ("alpha"	"\\mbfsanss"	#X1D600)
    ("alpha"	"\\mbfsanst"	#X1D601)
    ("alpha"	"\\mbfsansu"	#X1D602)
    ("alpha"	"\\mbfsansv"	#X1D603)
    ("alpha"	"\\mbfsansw"	#X1D604)
    ("alpha"	"\\mbfsansx"	#X1D605)
    ("alpha"	"\\mbfsansy"	#X1D606)
    ("alpha"	"\\mbfsansz"	#X1D607)
    ("alpha"	"\\mitsansA"	#X1D608)
    ("alpha"	"\\mitsansB"	#X1D609)
    ("alpha"	"\\mitsansC"	#X1D60A)
    ("alpha"	"\\mitsansD"	#X1D60B)
    ("alpha"	"\\mitsansE"	#X1D60C)
    ("alpha"	"\\mitsansF"	#X1D60D)
    ("alpha"	"\\mitsansG"	#X1D60E)
    ("alpha"	"\\mitsansH"	#X1D60F)
    ("alpha"	"\\mitsansI"	#X1D610)
    ("alpha"	"\\mitsansJ"	#X1D611)
    ("alpha"	"\\mitsansK"	#X1D612)
    ("alpha"	"\\mitsansL"	#X1D613)
    ("alpha"	"\\mitsansM"	#X1D614)
    ("alpha"	"\\mitsansN"	#X1D615)
    ("alpha"	"\\mitsansO"	#X1D616)
    ("alpha"	"\\mitsansP"	#X1D617)
    ("alpha"	"\\mitsansQ"	#X1D618)
    ("alpha"	"\\mitsansR"	#X1D619)
    ("alpha"	"\\mitsansS"	#X1D61A)
    ("alpha"	"\\mitsansT"	#X1D61B)
    ("alpha"	"\\mitsansU"	#X1D61C)
    ("alpha"	"\\mitsansV"	#X1D61D)
    ("alpha"	"\\mitsansW"	#X1D61E)
    ("alpha"	"\\mitsansX"	#X1D61F)
    ("alpha"	"\\mitsansY"	#X1D620)
    ("alpha"	"\\mitsansZ"	#X1D621)
    ("alpha"	"\\mitsansa"	#X1D622)
    ("alpha"	"\\mitsansb"	#X1D623)
    ("alpha"	"\\mitsansc"	#X1D624)
    ("alpha"	"\\mitsansd"	#X1D625)
    ("alpha"	"\\mitsanse"	#X1D626)
    ("alpha"	"\\mitsansf"	#X1D627)
    ("alpha"	"\\mitsansg"	#X1D628)
    ("alpha"	"\\mitsansh"	#X1D629)
    ("alpha"	"\\mitsansi"	#X1D62A)
    ("alpha"	"\\mitsansj"	#X1D62B)
    ("alpha"	"\\mitsansk"	#X1D62C)
    ("alpha"	"\\mitsansl"	#X1D62D)
    ("alpha"	"\\mitsansm"	#X1D62E)
    ("alpha"	"\\mitsansn"	#X1D62F)
    ("alpha"	"\\mitsanso"	#X1D630)
    ("alpha"	"\\mitsansp"	#X1D631)
    ("alpha"	"\\mitsansq"	#X1D632)
    ("alpha"	"\\mitsansr"	#X1D633)
    ("alpha"	"\\mitsanss"	#X1D634)
    ("alpha"	"\\mitsanst"	#X1D635)
    ("alpha"	"\\mitsansu"	#X1D636)
    ("alpha"	"\\mitsansv"	#X1D637)
    ("alpha"	"\\mitsansw"	#X1D638)
    ("alpha"	"\\mitsansx"	#X1D639)
    ("alpha"	"\\mitsansy"	#X1D63A)
    ("alpha"	"\\mitsansz"	#X1D63B)
    ("alpha"	"\\mbfitsansA"	#X1D63C)
    ("alpha"	"\\mbfitsansB"	#X1D63D)
    ("alpha"	"\\mbfitsansC"	#X1D63E)
    ("alpha"	"\\mbfitsansD"	#X1D63F)
    ("alpha"	"\\mbfitsansE"	#X1D640)
    ("alpha"	"\\mbfitsansF"	#X1D641)
    ("alpha"	"\\mbfitsansG"	#X1D642)
    ("alpha"	"\\mbfitsansH"	#X1D643)
    ("alpha"	"\\mbfitsansI"	#X1D644)
    ("alpha"	"\\mbfitsansJ"	#X1D645)
    ("alpha"	"\\mbfitsansK"	#X1D646)
    ("alpha"	"\\mbfitsansL"	#X1D647)
    ("alpha"	"\\mbfitsansM"	#X1D648)
    ("alpha"	"\\mbfitsansN"	#X1D649)
    ("alpha"	"\\mbfitsansO"	#X1D64A)
    ("alpha"	"\\mbfitsansP"	#X1D64B)
    ("alpha"	"\\mbfitsansQ"	#X1D64C)
    ("alpha"	"\\mbfitsansR"	#X1D64D)
    ("alpha"	"\\mbfitsansS"	#X1D64E)
    ("alpha"	"\\mbfitsansT"	#X1D64F)
    ("alpha"	"\\mbfitsansU"	#X1D650)
    ("alpha"	"\\mbfitsansV"	#X1D651)
    ("alpha"	"\\mbfitsansW"	#X1D652)
    ("alpha"	"\\mbfitsansX"	#X1D653)
    ("alpha"	"\\mbfitsansY"	#X1D654)
    ("alpha"	"\\mbfitsansZ"	#X1D655)
    ("alpha"	"\\mbfitsansa"	#X1D656)
    ("alpha"	"\\mbfitsansb"	#X1D657)
    ("alpha"	"\\mbfitsansc"	#X1D658)
    ("alpha"	"\\mbfitsansd"	#X1D659)
    ("alpha"	"\\mbfitsanse"	#X1D65A)
    ("alpha"	"\\mbfitsansf"	#X1D65B)
    ("alpha"	"\\mbfitsansg"	#X1D65C)
    ("alpha"	"\\mbfitsansh"	#X1D65D)
    ("alpha"	"\\mbfitsansi"	#X1D65E)
    ("alpha"	"\\mbfitsansj"	#X1D65F)
    ("alpha"	"\\mbfitsansk"	#X1D660)
    ("alpha"	"\\mbfitsansl"	#X1D661)
    ("alpha"	"\\mbfitsansm"	#X1D662)
    ("alpha"	"\\mbfitsansn"	#X1D663)
    ("alpha"	"\\mbfitsanso"	#X1D664)
    ("alpha"	"\\mbfitsansp"	#X1D665)
    ("alpha"	"\\mbfitsansq"	#X1D666)
    ("alpha"	"\\mbfitsansr"	#X1D667)
    ("alpha"	"\\mbfitsanss"	#X1D668)
    ("alpha"	"\\mbfitsanst"	#X1D669)
    ("alpha"	"\\mbfitsansu"	#X1D66A)
    ("alpha"	"\\mbfitsansv"	#X1D66B)
    ("alpha"	"\\mbfitsansw"	#X1D66C)
    ("alpha"	"\\mbfitsansx"	#X1D66D)
    ("alpha"	"\\mbfitsansy"	#X1D66E)
    ("alpha"	"\\mbfitsansz"	#X1D66F)
    ("alpha"	"\\mttA"	#X1D670)
    ("alpha"	"\\mttB"	#X1D671)
    ("alpha"	"\\mttC"	#X1D672)
    ("alpha"	"\\mttD"	#X1D673)
    ("alpha"	"\\mttE"	#X1D674)
    ("alpha"	"\\mttF"	#X1D675)
    ("alpha"	"\\mttG"	#X1D676)
    ("alpha"	"\\mttH"	#X1D677)
    ("alpha"	"\\mttI"	#X1D678)
    ("alpha"	"\\mttJ"	#X1D679)
    ("alpha"	"\\mttK"	#X1D67A)
    ("alpha"	"\\mttL"	#X1D67B)
    ("alpha"	"\\mttM"	#X1D67C)
    ("alpha"	"\\mttN"	#X1D67D)
    ("alpha"	"\\mttO"	#X1D67E)
    ("alpha"	"\\mttP"	#X1D67F)
    ("alpha"	"\\mttQ"	#X1D680)
    ("alpha"	"\\mttR"	#X1D681)
    ("alpha"	"\\mttS"	#X1D682)
    ("alpha"	"\\mttT"	#X1D683)
    ("alpha"	"\\mttU"	#X1D684)
    ("alpha"	"\\mttV"	#X1D685)
    ("alpha"	"\\mttW"	#X1D686)
    ("alpha"	"\\mttX"	#X1D687)
    ("alpha"	"\\mttY"	#X1D688)
    ("alpha"	"\\mttZ"	#X1D689)
    ("alpha"	"\\mtta"	#X1D68A)
    ("alpha"	"\\mttb"	#X1D68B)
    ("alpha"	"\\mttc"	#X1D68C)
    ("alpha"	"\\mttd"	#X1D68D)
    ("alpha"	"\\mtte"	#X1D68E)
    ("alpha"	"\\mttf"	#X1D68F)
    ("alpha"	"\\mttg"	#X1D690)
    ("alpha"	"\\mtth"	#X1D691)
    ("alpha"	"\\mtti"	#X1D692)
    ("alpha"	"\\mttj"	#X1D693)
    ("alpha"	"\\mttk"	#X1D694)
    ("alpha"	"\\mttl"	#X1D695)
    ("alpha"	"\\mttm"	#X1D696)
    ("alpha"	"\\mttn"	#X1D697)
    ("alpha"	"\\mtto"	#X1D698)
    ("alpha"	"\\mttp"	#X1D699)
    ("alpha"	"\\mttq"	#X1D69A)
    ("alpha"	"\\mttr"	#X1D69B)
    ("alpha"	"\\mtts"	#X1D69C)
    ("alpha"	"\\mttt"	#X1D69D)
    ("alpha"	"\\mttu"	#X1D69E)
    ("alpha"	"\\mttv"	#X1D69F)
    ("alpha"	"\\mttw"	#X1D6A0)
    ("alpha"	"\\mttx"	#X1D6A1)
    ("alpha"	"\\mtty"	#X1D6A2)
    ("alpha"	"\\mttz"	#X1D6A3)
    ("alpha"	"\\imath"	#X1D6A4)
    ("alpha"	"\\jmath"	#X1D6A5)
    ("alpha"	"\\mbfAlpha"	#X1D6A8)
    ("alpha"	"\\mbfBeta"	#X1D6A9)
    ("alpha"	"\\mbfGamma"	#X1D6AA)
    ("alpha"	"\\mbfDelta"	#X1D6AB)
    ("alpha"	"\\mbfEpsilon"	#X1D6AC)
    ("alpha"	"\\mbfZeta"	#X1D6AD)
    ("alpha"	"\\mbfEta"	#X1D6AE)
    ("alpha"	"\\mbfTheta"	#X1D6AF)
    ("alpha"	"\\mbfIota"	#X1D6B0)
    ("alpha"	"\\mbfKappa"	#X1D6B1)
    ("alpha"	"\\mbfLambda"	#X1D6B2)
    ("alpha"	"\\mbfMu"	#X1D6B3)
    ("alpha"	"\\mbfNu"	#X1D6B4)
    ("alpha"	"\\mbfXi"	#X1D6B5)
    ("alpha"	"\\mbfOmicron"	#X1D6B6)
    ("alpha"	"\\mbfPi"	#X1D6B7)
    ("alpha"	"\\mbfRho"	#X1D6B8)
    ("alpha"	"\\mbfvarTheta"	#X1D6B9)
    ("alpha"	"\\mbfSigma"	#X1D6BA)
    ("alpha"	"\\mbfTau"	#X1D6BB)
    ("alpha"	"\\mbfUpsilon"	#X1D6BC)
    ("alpha"	"\\mbfPhi"	#X1D6BD)
    ("alpha"	"\\mbfChi"	#X1D6BE)
    ("alpha"	"\\mbfPsi"	#X1D6BF)
    ("alpha"	"\\mbfOmega"	#X1D6C0)
    ("ord"	"\\mbfnabla"	#X1D6C1)
    ("alpha"	"\\mbfalpha"	#X1D6C2)
    ("alpha"	"\\mbfbeta"	#X1D6C3)
    ("alpha"	"\\mbfgamma"	#X1D6C4)
    ("alpha"	"\\mbfdelta"	#X1D6C5)
    ("alpha"	"\\mbfepsilon"	#X1D6C6)
    ("alpha"	"\\mbfzeta"	#X1D6C7)
    ("alpha"	"\\mbfeta"	#X1D6C8)
    ("alpha"	"\\mbftheta"	#X1D6C9)
    ("alpha"	"\\mbfiota"	#X1D6CA)
    ("alpha"	"\\mbfkappa"	#X1D6CB)
    ("alpha"	"\\mbflambda"	#X1D6CC)
    ("alpha"	"\\mbfmu"	#X1D6CD)
    ("alpha"	"\\mbfnu"	#X1D6CE)
    ("alpha"	"\\mbfxi"	#X1D6CF)
    ("alpha"	"\\mbfomicron"	#X1D6D0)
    ("alpha"	"\\mbfpi"	#X1D6D1)
    ("alpha"	"\\mbfrho"	#X1D6D2)
    ("alpha"	"\\mbfvarsigma"	#X1D6D3)
    ("alpha"	"\\mbfsigma"	#X1D6D4)
    ("alpha"	"\\mbftau"	#X1D6D5)
    ("alpha"	"\\mbfupsilon"	#X1D6D6)
    ("alpha"	"\\mbfvarphi"	#X1D6D7)
    ("alpha"	"\\mbfchi"	#X1D6D8)
    ("alpha"	"\\mbfpsi"	#X1D6D9)
    ("alpha"	"\\mbfomega"	#X1D6DA)
    ("ord"	"\\mbfpartial"	#X1D6DB)
    ("alpha"	"\\mbfvarepsilon"	#X1D6DC)
    ("alpha"	"\\mbfvartheta"	#X1D6DD)
    ("alpha"	"\\mbfvarkappa"	#X1D6DE)
    ("alpha"	"\\mbfphi"	#X1D6DF)
    ("alpha"	"\\mbfvarrho"	#X1D6E0)
    ("alpha"	"\\mbfvarpi"	#X1D6E1)
    ("alpha"	"\\mitAlpha"	#X1D6E2)
    ("alpha"	"\\mitBeta"	#X1D6E3)
    ("alpha"	"\\mitGamma"	#X1D6E4)
    ("alpha"	"\\mitDelta"	#X1D6E5)
    ("alpha"	"\\mitEpsilon"	#X1D6E6)
    ("alpha"	"\\mitZeta"	#X1D6E7)
    ("alpha"	"\\mitEta"	#X1D6E8)
    ("alpha"	"\\mitTheta"	#X1D6E9)
    ("alpha"	"\\mitIota"	#X1D6EA)
    ("alpha"	"\\mitKappa"	#X1D6EB)
    ("alpha"	"\\mitLambda"	#X1D6EC)
    ("alpha"	"\\mitMu"	#X1D6ED)
    ("alpha"	"\\mitNu"	#X1D6EE)
    ("alpha"	"\\mitXi"	#X1D6EF)
    ("alpha"	"\\mitOmicron"	#X1D6F0)
    ("alpha"	"\\mitPi"	#X1D6F1)
    ("alpha"	"\\mitRho"	#X1D6F2)
    ("alpha"	"\\mitvarTheta"	#X1D6F3)
    ("alpha"	"\\mitSigma"	#X1D6F4)
    ("alpha"	"\\mitTau"	#X1D6F5)
    ("alpha"	"\\mitUpsilon"	#X1D6F6)
    ("alpha"	"\\mitPhi"	#X1D6F7)
    ("alpha"	"\\mitChi"	#X1D6F8)
    ("alpha"	"\\mitPsi"	#X1D6F9)
    ("alpha"	"\\mitOmega"	#X1D6FA)
    ("ord"	"\\mitnabla"	#X1D6FB)
    ("alpha"	"\\mitalpha"	#X1D6FC)
    ("alpha"	"\\mitbeta"	#X1D6FD)
    ("alpha"	"\\mitgamma"	#X1D6FE)
    ("alpha"	"\\mitdelta"	#X1D6FF)
    ("alpha"	"\\mitepsilon"	#X1D700)
    ("alpha"	"\\mitzeta"	#X1D701)
    ("alpha"	"\\miteta"	#X1D702)
    ("alpha"	"\\mittheta"	#X1D703)
    ("alpha"	"\\mitiota"	#X1D704)
    ("alpha"	"\\mitkappa"	#X1D705)
    ("alpha"	"\\mitlambda"	#X1D706)
    ("alpha"	"\\mitmu"	#X1D707)
    ("alpha"	"\\mitnu"	#X1D708)
    ("alpha"	"\\mitxi"	#X1D709)
    ("alpha"	"\\mitomicron"	#X1D70A)
    ("alpha"	"\\mitpi"	#X1D70B)
    ("alpha"	"\\mitrho"	#X1D70C)
    ("alpha"	"\\mitvarsigma"	#X1D70D)
    ("alpha"	"\\mitsigma"	#X1D70E)
    ("alpha"	"\\mittau"	#X1D70F)
    ("alpha"	"\\mitupsilon"	#X1D710)
    ("alpha"	"\\mitphi"	#X1D711)
    ("alpha"	"\\mitchi"	#X1D712)
    ("alpha"	"\\mitpsi"	#X1D713)
    ("alpha"	"\\mitomega"	#X1D714)
    ("ord"	"\\mitpartial"	#X1D715)
    ("alpha"	"\\mitvarepsilon"	#X1D716)
    ("alpha"	"\\mitvartheta"	#X1D717)
    ("alpha"	"\\mitvarkappa"	#X1D718)
    ("alpha"	"\\mitvarphi"	#X1D719)
    ("alpha"	"\\mitvarrho"	#X1D71A)
    ("alpha"	"\\mitvarpi"	#X1D71B)
    ("alpha"	"\\mbfitAlpha"	#X1D71C)
    ("alpha"	"\\mbfitBeta"	#X1D71D)
    ("alpha"	"\\mbfitGamma"	#X1D71E)
    ("alpha"	"\\mbfitDelta"	#X1D71F)
    ("alpha"	"\\mbfitEpsilon"	#X1D720)
    ("alpha"	"\\mbfitZeta"	#X1D721)
    ("alpha"	"\\mbfitEta"	#X1D722)
    ("alpha"	"\\mbfitTheta"	#X1D723)
    ("alpha"	"\\mbfitIota"	#X1D724)
    ("alpha"	"\\mbfitKappa"	#X1D725)
    ("alpha"	"\\mbfitLambda"	#X1D726)
    ("alpha"	"\\mbfitMu"	#X1D727)
    ("alpha"	"\\mbfitNu"	#X1D728)
    ("alpha"	"\\mbfitXi"	#X1D729)
    ("alpha"	"\\mbfitOmicron"	#X1D72A)
    ("alpha"	"\\mbfitPi"	#X1D72B)
    ("alpha"	"\\mbfitRho"	#X1D72C)
    ("alpha"	"\\mbfitvarTheta"	#X1D72D)
    ("alpha"	"\\mbfitSigma"	#X1D72E)
    ("alpha"	"\\mbfitTau"	#X1D72F)
    ("alpha"	"\\mbfitUpsilon"	#X1D730)
    ("alpha"	"\\mbfitPhi"	#X1D731)
    ("alpha"	"\\mbfitChi"	#X1D732)
    ("alpha"	"\\mbfitPsi"	#X1D733)
    ("alpha"	"\\mbfitOmega"	#X1D734)
    ("ord"	"\\mbfitnabla"	#X1D735)
    ("alpha"	"\\mbfitalpha"	#X1D736)
    ("alpha"	"\\mbfitbeta"	#X1D737)
    ("alpha"	"\\mbfitgamma"	#X1D738)
    ("alpha"	"\\mbfitdelta"	#X1D739)
    ("alpha"	"\\mbfitepsilon"	#X1D73A)
    ("alpha"	"\\mbfitzeta"	#X1D73B)
    ("alpha"	"\\mbfiteta"	#X1D73C)
    ("alpha"	"\\mbfittheta"	#X1D73D)
    ("alpha"	"\\mbfitiota"	#X1D73E)
    ("alpha"	"\\mbfitkappa"	#X1D73F)
    ("alpha"	"\\mbfitlambda"	#X1D740)
    ("alpha"	"\\mbfitmu"	#X1D741)
    ("alpha"	"\\mbfitnu"	#X1D742)
    ("alpha"	"\\mbfitxi"	#X1D743)
    ("alpha"	"\\mbfitomicron"	#X1D744)
    ("alpha"	"\\mbfitpi"	#X1D745)
    ("alpha"	"\\mbfitrho"	#X1D746)
    ("alpha"	"\\mbfitvarsigma"	#X1D747)
    ("alpha"	"\\mbfitsigma"	#X1D748)
    ("alpha"	"\\mbfittau"	#X1D749)
    ("alpha"	"\\mbfitupsilon"	#X1D74A)
    ("alpha"	"\\mbfitphi"	#X1D74B)
    ("alpha"	"\\mbfitchi"	#X1D74C)
    ("alpha"	"\\mbfitpsi"	#X1D74D)
    ("alpha"	"\\mbfitomega"	#X1D74E)
    ("ord"	"\\mbfitpartial"	#X1D74F)
    ("alpha"	"\\mbfitvarepsilon"	#X1D750)
    ("alpha"	"\\mbfitvartheta"	#X1D751)
    ("alpha"	"\\mbfitvarkappa"	#X1D752)
    ("alpha"	"\\mbfitvarphi"	#X1D753)
    ("alpha"	"\\mbfitvarrho"	#X1D754)
    ("alpha"	"\\mbfitvarpi"	#X1D755)
    ("alpha"	"\\mbfsansAlpha"	#X1D756)
    ("alpha"	"\\mbfsansBeta"	#X1D757)
    ("alpha"	"\\mbfsansGamma"	#X1D758)
    ("alpha"	"\\mbfsansDelta"	#X1D759)
    ("alpha"	"\\mbfsansEpsilon"	#X1D75A)
    ("alpha"	"\\mbfsansZeta"	#X1D75B)
    ("alpha"	"\\mbfsansEta"	#X1D75C)
    ("alpha"	"\\mbfsansTheta"	#X1D75D)
    ("alpha"	"\\mbfsansIota"	#X1D75E)
    ("alpha"	"\\mbfsansKappa"	#X1D75F)
    ("alpha"	"\\mbfsansLambda"	#X1D760)
    ("alpha"	"\\mbfsansMu"	#X1D761)
    ("alpha"	"\\mbfsansNu"	#X1D762)
    ("alpha"	"\\mbfsansXi"	#X1D763)
    ("alpha"	"\\mbfsansOmicron"	#X1D764)
    ("alpha"	"\\mbfsansPi"	#X1D765)
    ("alpha"	"\\mbfsansRho"	#X1D766)
    ("alpha"	"\\mbfsansvarTheta"	#X1D767)
    ("alpha"	"\\mbfsansSigma"	#X1D768)
    ("alpha"	"\\mbfsansTau"	#X1D769)
    ("alpha"	"\\mbfsansUpsilon"	#X1D76A)
    ("alpha"	"\\mbfsansPhi"	#X1D76B)
    ("alpha"	"\\mbfsansChi"	#X1D76C)
    ("alpha"	"\\mbfsansPsi"	#X1D76D)
    ("alpha"	"\\mbfsansOmega"	#X1D76E)
    ("ord"	"\\mbfsansnabla"	#X1D76F)
    ("alpha"	"\\mbfsansalpha"	#X1D770)
    ("alpha"	"\\mbfsansbeta"	#X1D771)
    ("alpha"	"\\mbfsansgamma"	#X1D772)
    ("alpha"	"\\mbfsansdelta"	#X1D773)
    ("alpha"	"\\mbfsansepsilon"	#X1D774)
    ("alpha"	"\\mbfsanszeta"	#X1D775)
    ("alpha"	"\\mbfsanseta"	#X1D776)
    ("alpha"	"\\mbfsanstheta"	#X1D777)
    ("alpha"	"\\mbfsansiota"	#X1D778)
    ("alpha"	"\\mbfsanskappa"	#X1D779)
    ("alpha"	"\\mbfsanslambda"	#X1D77A)
    ("alpha"	"\\mbfsansmu"	#X1D77B)
    ("alpha"	"\\mbfsansnu"	#X1D77C)
    ("alpha"	"\\mbfsansxi"	#X1D77D)
    ("alpha"	"\\mbfsansomicron"	#X1D77E)
    ("alpha"	"\\mbfsanspi"	#X1D77F)
    ("alpha"	"\\mbfsansrho"	#X1D780)
    ("alpha"	"\\mbfsansvarsigma"	#X1D781)
    ("alpha"	"\\mbfsanssigma"	#X1D782)
    ("alpha"	"\\mbfsanstau"	#X1D783)
    ("alpha"	"\\mbfsansupsilon"	#X1D784)
    ("alpha"	"\\mbfsansphi"	#X1D785)
    ("alpha"	"\\mbfsanschi"	#X1D786)
    ("alpha"	"\\mbfsanspsi"	#X1D787)
    ("alpha"	"\\mbfsansomega"	#X1D788)
    ("ord"	"\\mbfsanspartial"	#X1D789)
    ("alpha"	"\\mbfsansvarepsilon"	#X1D78A)
    ("alpha"	"\\mbfsansvartheta"	#X1D78B)
    ("alpha"	"\\mbfsansvarkappa"	#X1D78C)
    ("alpha"	"\\mbfsansvarphi"	#X1D78D)
    ("alpha"	"\\mbfsansvarrho"	#X1D78E)
    ("alpha"	"\\mbfsansvarpi"	#X1D78F)
    ("alpha"	"\\mbfitsansAlpha"	#X1D790)
    ("alpha"	"\\mbfitsansBeta"	#X1D791)
    ("alpha"	"\\mbfitsansGamma"	#X1D792)
    ("alpha"	"\\mbfitsansDelta"	#X1D793)
    ("alpha"	"\\mbfitsansEpsilon"	#X1D794)
    ("alpha"	"\\mbfitsansZeta"	#X1D795)
    ("alpha"	"\\mbfitsansEta"	#X1D796)
    ("alpha"	"\\mbfitsansTheta"	#X1D797)
    ("alpha"	"\\mbfitsansIota"	#X1D798)
    ("alpha"	"\\mbfitsansKappa"	#X1D799)
    ("alpha"	"\\mbfitsansLambda"	#X1D79A)
    ("alpha"	"\\mbfitsansMu"	#X1D79B)
    ("alpha"	"\\mbfitsansNu"	#X1D79C)
    ("alpha"	"\\mbfitsansXi"	#X1D79D)
    ("alpha"	"\\mbfitsansOmicron"	#X1D79E)
    ("alpha"	"\\mbfitsansPi"	#X1D79F)
    ("alpha"	"\\mbfitsansRho"	#X1D7A0)
    ("alpha"	"\\mbfitsansvarTheta"	#X1D7A1)
    ("alpha"	"\\mbfitsansSigma"	#X1D7A2)
    ("alpha"	"\\mbfitsansTau"	#X1D7A3)
    ("alpha"	"\\mbfitsansUpsilon"	#X1D7A4)
    ("alpha"	"\\mbfitsansPhi"	#X1D7A5)
    ("alpha"	"\\mbfitsansChi"	#X1D7A6)
    ("alpha"	"\\mbfitsansPsi"	#X1D7A7)
    ("alpha"	"\\mbfitsansOmega"	#X1D7A8)
    ("ord"	"\\mbfitsansnabla"	#X1D7A9)
    ("alpha"	"\\mbfitsansalpha"	#X1D7AA)
    ("alpha"	"\\mbfitsansbeta"	#X1D7AB)
    ("alpha"	"\\mbfitsansgamma"	#X1D7AC)
    ("alpha"	"\\mbfitsansdelta"	#X1D7AD)
    ("alpha"	"\\mbfitsansepsilon"	#X1D7AE)
    ("alpha"	"\\mbfitsanszeta"	#X1D7AF)
    ("alpha"	"\\mbfitsanseta"	#X1D7B0)
    ("alpha"	"\\mbfitsanstheta"	#X1D7B1)
    ("alpha"	"\\mbfitsansiota"	#X1D7B2)
    ("alpha"	"\\mbfitsanskappa"	#X1D7B3)
    ("alpha"	"\\mbfitsanslambda"	#X1D7B4)
    ("alpha"	"\\mbfitsansmu"	#X1D7B5)
    ("alpha"	"\\mbfitsansnu"	#X1D7B6)
    ("alpha"	"\\mbfitsansxi"	#X1D7B7)
    ("alpha"	"\\mbfitsansomicron"	#X1D7B8)
    ("alpha"	"\\mbfitsanspi"	#X1D7B9)
    ("alpha"	"\\mbfitsansrho"	#X1D7BA)
    ("alpha"	"\\mbfitsansvarsigma"	#X1D7BB)
    ("alpha"	"\\mbfitsanssigma"	#X1D7BC)
    ("alpha"	"\\mbfitsanstau"	#X1D7BD)
    ("alpha"	"\\mbfitsansupsilon"	#X1D7BE)
    ("alpha"	"\\mbfitsansphi"	#X1D7BF)
    ("alpha"	"\\mbfitsanschi"	#X1D7C0)
    ("alpha"	"\\mbfitsanspsi"	#X1D7C1)
    ("alpha"	"\\mbfitsansomega"	#X1D7C2)
    ("ord"	"\\mbfitsanspartial"	#X1D7C3)
    ("alpha"	"\\mbfitsansvarepsilon"	#X1D7C4)
    ("alpha"	"\\mbfitsansvartheta"	#X1D7C5)
    ("alpha"	"\\mbfitsansvarkappa"	#X1D7C6)
    ("alpha"	"\\mbfitsansvarphi"	#X1D7C7)
    ("alpha"	"\\mbfitsansvarrho"	#X1D7C8)
    ("alpha"	"\\mbfitsansvarpi"	#X1D7C9)
    ("alpha"	"\\mbfDigamma"	#X1D7CA)
    ("alpha"	"\\mbfdigamma"	#X1D7CB)
    ("ord"	"\\mbfzero"	#X1D7CE)
    ("ord"	"\\mbfone"	#X1D7CF)
    ("ord"	"\\mbftwo"	#X1D7D0)
    ("ord"	"\\mbfthree"	#X1D7D1)
    ("ord"	"\\mbffour"	#X1D7D2)
    ("ord"	"\\mbffive"	#X1D7D3)
    ("ord"	"\\mbfsix"	#X1D7D4)
    ("ord"	"\\mbfseven"	#X1D7D5)
    ("ord"	"\\mbfeight"	#X1D7D6)
    ("ord"	"\\mbfnine"	#X1D7D7)
    ("ord"	"\\Bbbzero"	#X1D7D8)
    ("ord"	"\\Bbbone"	#X1D7D9)
    ("ord"	"\\Bbbtwo"	#X1D7DA)
    ("ord"	"\\Bbbthree"	#X1D7DB)
    ("ord"	"\\Bbbfour"	#X1D7DC)
    ("ord"	"\\Bbbfive"	#X1D7DD)
    ("ord"	"\\Bbbsix"	#X1D7DE)
    ("ord"	"\\Bbbseven"	#X1D7DF)
    ("ord"	"\\Bbbeight"	#X1D7E0)
    ("ord"	"\\Bbbnine"	#X1D7E1)
    ("ord"	"\\msanszero"	#X1D7E2)
    ("ord"	"\\msansone"	#X1D7E3)
    ("ord"	"\\msanstwo"	#X1D7E4)
    ("ord"	"\\msansthree"	#X1D7E5)
    ("ord"	"\\msansfour"	#X1D7E6)
    ("ord"	"\\msansfive"	#X1D7E7)
    ("ord"	"\\msanssix"	#X1D7E8)
    ("ord"	"\\msansseven"	#X1D7E9)
    ("ord"	"\\msanseight"	#X1D7EA)
    ("ord"	"\\msansnine"	#X1D7EB)
    ("ord"	"\\mbfsanszero"	#X1D7EC)
    ("ord"	"\\mbfsansone"	#X1D7ED)
    ("ord"	"\\mbfsanstwo"	#X1D7EE)
    ("ord"	"\\mbfsansthree"	#X1D7EF)
    ("ord"	"\\mbfsansfour"	#X1D7F0)
    ("ord"	"\\mbfsansfive"	#X1D7F1)
    ("ord"	"\\mbfsanssix"	#X1D7F2)
    ("ord"	"\\mbfsansseven"	#X1D7F3)
    ("ord"	"\\mbfsanseight"	#X1D7F4)
    ("ord"	"\\mbfsansnine"	#X1D7F5)
    ("ord"	"\\mttzero"	#X1D7F6)
    ("ord"	"\\mttone"	#X1D7F7)
    ("ord"	"\\mtttwo"	#X1D7F8)
    ("ord"	"\\mttthree"	#X1D7F9)
    ("ord"	"\\mttfour"	#X1D7FA)
    ("ord"	"\\mttfive"	#X1D7FB)
    ("ord"	"\\mttsix"	#X1D7FC)
    ("ord"	"\\mttseven"	#X1D7FD)
    ("ord"	"\\mtteight"	#X1D7FE)
    ("ord"	"\\mttnine"	#X1D7FF))
  "Extended list of mathematical symbols")


(defconst math-symbol-list-latex-commands
  '("address" "addtocounter" "addtolength" "addvspace" "Alph" "alph" "Alph
    example" "alsoname" "and for author" "appendix" "arabic" "arraycolsep"
    "arrayrulewidth" "arraystretch" "baselineskip"
    "baselinestretch" "begin" "bf" "bfseries" "bibitem" "bibliography"
    "bibliographystyle" "bigskip" "bigskipamount" "bmod" "boldmath"
    "bottomfraction" "cal" "caption" "cc" "centering"
    "chapter" "circle" "cite" "cleardoublepage" "clearpage" "cline" "closing"
    "columnsep" "columnseprule" "columnwidth" "contentsline" "copyright"
    "dag" "dashbox" "day" "dblfloatpagefraction"
    "dblfloatsep" "dbltextfloatsep" "dbltopfraction" "ddag" "depth"
    "displaystyle" "documentclass" "dotfill" "doublerulesep" "emph" "encl"
    "enlargethispage" "enumi" "enumii" "enumiii" "enumiv" "evensidemargin"
    "fbox" "fboxrule" "fboxsep" "fill" "floatpagefraction" "floatsep"
    "flushbottom" "fnsymbol" "fontencoding" "fontfamily" "fontseries"
    "fontshape" "fontsize" "footnote" "footnotemark" "footnoterule"
    "footnotesep" "footnotesize" "footnotetext" "footskip" "frame" "framebox"
    "fussy" "gets" "glossary" "glossaryentry" 
    "headheight" "headsep" "height" "hfill" "hline" "hrulefill" "hspace"
    "Huge" "huge" "hyphenation" "iff" "include" "includeonly"
    "indent" "index" "indexentry" "input" "intextsep"
    "item" "itemindent" "itemsep" "itshape" "kill"
    "label" "labelenumi" "labelenumii" "labelenumiii" "labelenumiv"
    "labelitemi" "labelitemii" "labelitemiii" "labelitemiv" "labelsep"
    "labelwidth" "land" "LARGE" "Large" "large" "LaTeX" "le" "left" "leadsto"
    "lefteqn" "leftmargin" "leftmargini" "leftmarginii" "leftmarginiii"
    "leftmarginiv" "leftmarginv" "leftmarginvi" "line" "linebreak"
    "linethickness" "linewidth" "listoffigures" "listoftables" "listparindent"
    "lnot" "location" "lor" "lq" "makebox" "makebox " "makeglossary"
    "makeindex" "makelabels" "maketitle" "marginpar" "marginparpush"
    "marginparsep" "marginparwidth" "mathbf" "mathcal" "mathnormal" "mathrm"
    "mathsf" "mathtt" "mathversion" "mbox" "mdseries" "medskip"
    "medskipamount" "month" "multicolumn" "multiput" "name" "newcommand"
    "newcounter" "newenvironment" "newfont" "newlength" "NEWLINE" "newline"
    "newpage" "newsavebox" "newtheorem" "nocite" "nofiles" "noindent"
    "nolinebreak" "nonumber" "nopagebreak" "normalfont" "normalmarginpar"
    "normalsize" "oe" "onecolumn" "opening" "oval" "owns" "P" "pagebreak" "pagenumbering"
    "pageref" "pagestyle" "paragraph" "parbox" "parindent"
    "parsep" "parskip" "parskip example" "part" "partopsep" "pmod" "poptabs"
    "pounds" "protect" "ps" "pushtabs" "put" "raggedbottom" "raggedleft"
    "raggedright" "raisebox" "ref" "refstepcounter" "renewenvironment"
    "restorecr" "reversemarginpar" "right" "rightmargin" "rm" "rmfamily"
    "roman" "rq" "rule" "savebox" "sbox" "sc" "scriptsize" "scshape"
    "section" "seename" "selectfont" "setcounter" "setlength" "settodepth"
    "settoheight" "settowidth" "sf" "sffamily" "shortstack" "signature" "sl"
    "slshape" "small" "smallint" "smallskip" "smallskipamount" "SPACE" "ss"
    "startbreaks" "stepcounter" "stop" "stopbreaks" "subparagraph"
    "subsection" "subsubsection" "symbol" "TAB"
    "tabbingsep" "tabcolsep" "tableofcontents" "telephone" "TeX" "textbf"
    "textfloatsep" "textfraction" "textheight" "textit" "textmd" "textnormal"
    "textrm" "textsc" "textsf" "textsl" "texttt" "textup" "textwidth"
    "thicklines" "thinlines" "thinspace" "thispagestyle" "tiny" "to" "today"
    "topfraction" "topmargin" "topsep" "topskip" "totalheight" "tt" "ttfamily"
    "twocolumn" "typein" "typeout" "u " "unboldmath"
    "unitlength" "upshape" "usebox" "usecounter" "usefont" "usepackage"
    "value" "vector" "verb" "vert" "vfill" "vline" "vspace"
    "width" "year")
  "List of the latex commands.")

(provide 'math-symbol-lists)

;;; math-symbol-lists.el ends here
